@@ -341,12 +341,13 @@ class AbstractQueryStopView(PsycopgMixin, RenderableView):  # pylint: disable=lo
         """
         Check the form for *cancel* button press and cancel the action.
         """
-        if getattr(form, vial.const.FORM_ACTION_CANCEL).data:
-            self.flash(
-                flask.Markup(self.get_message_cancel(**kwargs)),
-                vial.const.FLASH_INFO
-            )
-            return self.redirect(default_url = self.get_url_next())
+        if hasattr(form, vial.const.FORM_ACTION_CANCEL):
+            if getattr(form, vial.const.FORM_ACTION_CANCEL).data:
+                self.flash(
+                    flask.Markup(self.get_message_cancel(**kwargs)),
+                    vial.const.FLASH_INFO
+                )
+                return self.redirect(default_url = self.get_url_next())
 
         return None
 
@@ -523,10 +524,6 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
             order_by(FilterModel.createtime.desc()).\
             all()
 
-        self.response_context['settingsrep_muted'] = self.dbquery(SettingsReportingModel).\
-            filter(SettingsReportingModel.mute == True).\
-            order_by(SettingsReportingModel.createtime.desc()).\
-            all()
         self.response_context['settingsrep_redirected'] = self.dbquery(SettingsReportingModel).\
             filter(SettingsReportingModel.redirect == True).\
             order_by(SettingsReportingModel.createtime.desc()).\
@@ -535,16 +532,9 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, SimpleView):  # pylint: disable=
             filter(SettingsReportingModel.mode == mentat.const.REPORTING_MODE_NONE).\
             order_by(SettingsReportingModel.createtime.desc()).\
             all()
-        self.response_context['settingsrep_attachcsv'] = self.dbquery(SettingsReportingModel).\
-            filter(SettingsReportingModel.attachments.in_([mentat.const.REPORTING_ATTACH_CSV, mentat.const.REPORTING_ATTACH_ALL])).\
-            order_by(SettingsReportingModel.createtime.desc()).\
-            all()
         self.response_context['settingsrep_emailscust'] = self.dbquery(SettingsReportingModel).\
-            filter(SettingsReportingModel.emails != []).\
-            order_by(SettingsReportingModel.createtime.desc()).\
-            all()
-        self.response_context['settingsrep_timingcust'] = self.dbquery(SettingsReportingModel).\
-            filter(SettingsReportingModel.timing == mentat.const.REPORTING_TIMING_CUSTOM).\
+            filter(SettingsReportingModel.emails_low != [] or SettingsReportingModel.emails_medium != [] or
+                   SettingsReportingModel.emails_high != [] or SettingsReportingModel.emails_critical != []).\
             order_by(SettingsReportingModel.createtime.desc()).\
             all()
 
