@@ -92,7 +92,7 @@ def process_rule(item):
             if ip6s:
                 rules.append('Source.IP6 IN ["{}"]'.format('","'.join(ip6s)))
 
-        item.filter = ' OR '.join(rules)
+        item.filter = ' AND '.join(rules)
 
 
 def to_tree(rule):
