@@ -51,7 +51,7 @@ class AbstractSearchView(PsycopgMixin, BaseSearchView):  # pylint: disable=local
     """
     authentication = True
 
-    authorization = [vial.acl.PERMISSION_POWER]
+    authorization = [vial.acl.PERMISSION_DEVELOPER]
 
     @classmethod
     def get_menu_title(cls, **kwargs):
@@ -167,10 +167,9 @@ class HostsBlueprint(VialBlueprint):
     def register_app(self, app):
         app.menu_main.add_entry(
             'view',
-            BLUEPRINT_NAME,
-            position = 150,
-            view = SearchView,
-            resptitle = True
+            'developer.{}'.format(BLUEPRINT_NAME),
+            position = 80,
+            view = SearchView
         )
 
         # Register context actions provided by this module.
