@@ -22,9 +22,9 @@ import wtforms
 import flask_wtf
 from flask_babel import lazy_gettext
 
+import vial.const
+import vial.forms
 import hawat.const
-import hawat.db
-import hawat.forms
 
 
 class SimpleHostSearchForm(flask_wtf.FlaskForm):
@@ -34,21 +34,23 @@ class SimpleHostSearchForm(flask_wtf.FlaskForm):
     host_addr = wtforms.StringField(
         lazy_gettext('Host address:'),
         validators = [
-            wtforms.validators.Required(),
-            hawat.forms.check_ip_record
+            wtforms.validators.DataRequired(),
+            vial.forms.check_ip_record
         ]
     )
-    dt_from = hawat.forms.SmartDateTimeField(
+    dt_from = vial.forms.SmartDateTimeField(
         lazy_gettext('Detection time from:'),
         validators = [
             wtforms.validators.Optional()
-        ]
+        ],
+        default = lambda: vial.forms.default_dt_with_delta(hawat.const.DEFAULT_RESULT_TIMEDELTA)
     )
-    dt_to = hawat.forms.SmartDateTimeField(
+    dt_to = vial.forms.SmartDateTimeField(
         lazy_gettext('Detection time to:'),
         validators = [
             wtforms.validators.Optional()
-        ]
+        ],
+        default = vial.forms.default_dt
     )
     submit = wtforms.SubmitField(
         lazy_gettext('Search')
