@@ -33,7 +33,8 @@ from flask_babel import gettext, lazy_gettext, force_locale, format_datetime
 
 import mentat.const
 import mentat.stats.idea
-from mentat.datatype.sqldb import EventReportModel, GroupModel, UserModel, ItemChangeLogModel
+from mentat.datatype.sqldb import EventReportModel, GroupModel, UserModel, ItemChangeLogModel, \
+    _asoc_groups_reports
 from mentat.const import tr_
 
 import hawat.const
@@ -62,7 +63,7 @@ def build_related_search_params(item):
         'st_to': item.dt_to,
         'severities': item.severity,
         'categories': 'Test',
-        'groups': [item.group.name],
+        'groups': [group.name for group in item.groups],
         'submit': gettext('Search')
     }
     if not item.flag_testdata:
@@ -85,14 +86,14 @@ def adjust_query_for_groups(query, groups):
         # Naive approach.
         #query = query.filter(model.group_id.in_([grp.id for grp in groups]))
         # "Joined" approach.
-        return query.join(GroupModel).filter(GroupModel.id.in_([grp.id for grp in groups]))
+        return query.join(_asoc_groups_reports).join(GroupModel).filter(GroupModel.id.in_([grp.id for grp in groups]))
 
     # For non-administrators restrict query only to groups they are member of.
     if not flask_login.current_user.has_role(vial.const.ROLE_ADMIN):
         # Naive approach.
         #query = query.filter(model.group.has(GroupModel.members.any(UserModel.id == flask_login.current_user.id)))
         # "Joined" approach.
-        return query.join(GroupModel).filter(GroupModel.members.any(UserModel.id == flask_login.current_user.id))
+        return query.join(_asoc_groups_reports).join(GroupModel).filter(GroupModel.members.any(UserModel.id == flask_login.current_user.id))
 
     return query
 
@@ -184,11 +185,14 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
 
     @classmethod
     def authorize_item_action(cls, **kwargs):
-        permission_mm = flask_principal.Permission(
-            vial.acl.MembershipNeed(kwargs['item'].group.id),
-            vial.acl.ManagementNeed(kwargs['item'].group.id)
-        )
-        return vial.acl.PERMISSION_POWER.can() or permission_mm.can()
+        for group in kwargs['item'].groups:
+            permission_mm = flask_principal.Permission(
+                vial.acl.MembershipNeed(group.id),
+                vial.acl.ManagementNeed(group.id)
+            )
+            if permission_mm.can():
+                return permission_mm.can()
+        return vial.acl.PERMISSION_POWER.can()
 
     @classmethod
     def get_breadcrumbs_menu(cls):  # pylint: disable=locally-disabled,unused-argument
@@ -241,14 +245,6 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
             icon = 'action-download',
             hidelegend = True
         )
-        action_menu.add_entry(
-            'endpoint',
-            'more.downloadcsv',
-            endpoint = 'reports.data',
-            title = lazy_gettext('Download data in CSV format (deprecated)'),
-            url = lambda **x: flask.url_for('reports.data', fileid = x['item'].label, filetype = 'csv'),
-            hidelegend = True
-        )
         action_menu.add_entry(
             'endpoint',
             'more.downloadjsonzip',
@@ -258,15 +254,6 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
             icon = 'action-download-zip',
             hidelegend = True
         )
-        action_menu.add_entry(
-            'endpoint',
-            'more.downloadcsvzip',
-            endpoint = 'reports.data',
-            title = lazy_gettext('Download compressed data in CSV format (deprecated)'),
-            url = lambda **x: flask.url_for('reports.data', fileid = x['item'].label, filetype = 'csvzip'),
-            icon = 'action-download-zip',
-            hidelegend = True
-        )
         return action_menu
 
     @staticmethod
@@ -313,6 +300,12 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
                 event_classes_dir  = flask.current_app.mconfig[mentat.const.CKEY_CORE_REPORTER][mentat.const.CKEY_CORE_REPORTER_EVENTCLASSESDIR],
                 escape_id          = ShowView.escape_id
             )
+            if self.response_context['item'].mail_to:
+                mails = self.response_context['item'].mail_to
+                self.response_context.update(
+                    to_mails = [x[3:] if x.startswith('to:') else x for x in mails if not x.startswith('cc:')],
+                    cc_mails = [x[3:] for x in mails if x.startswith('cc:')]
+                )
 
 
 class UnauthShowView(ShowView):  # pylint: disable=locally-disabled,too-many-ancestors
@@ -370,25 +363,17 @@ class DataView(FileIdView):
             fileext = 'json'
         elif filetype == 'jsonzip':
             fileext = 'json.zip'
-        elif filetype == 'csv':
-            fileext = 'csv'
-        elif filetype == 'csvzip':
-            fileext = 'csv.zip'
         else:
             raise ValueError("Requested invalid data file type '{}'".format(filetype))
         return 'security-report-{}.{}'.format(fileid, fileext)
 
 
-class DashboardView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disable=locally-disabled,too-many-ancestors
+class AbstractDashboardView(SQLAlchemyMixin, BaseSearchView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
-    View responsible for presenting reporting dashboard.
+    Base class responsible for presenting reporting dashboard.
     """
     authentication = True
 
-    @classmethod
-    def get_view_name(cls):
-        return 'dashboard'
-
     @classmethod
     def get_view_icon(cls):
         return 'module-{}'.format(cls.module_name)
@@ -445,12 +430,20 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disa
             if not dt_to:
                 dt_to = datetime.datetime.utcnow()
 
+            stats = mentat.stats.idea.aggregate_stats_reports(items, dt_from, dt_to)
+
+            # Remove to: and cc: prefixes from emails.
+            if 'emails' in stats:
+                d = {}
+                for k, v in stats['emails'].items():
+                    key = k[3:] if k.startswith('to:') or k.startswith('cc:') else k
+                    if not key in d:
+                        d[key] = 0
+                    d[key] += v
+                stats['emails'] = d
+
             self.response_context.update(
-                statistics = mentat.stats.idea.aggregate_stats_reports(
-                    items,
-                    dt_from,
-                    dt_to
-                )
+                statistics = stats
             )
 
     def do_before_response(self, **kwargs):
@@ -459,6 +452,38 @@ class DashboardView(HTMLMixin, SQLAlchemyMixin, BaseSearchView):  # pylint: disa
         )
 
 
+class DashboardView(HTMLMixin, AbstractDashboardView):  # pylint: disable=locally-disabled,too-many-ancestors
+    """
+    View responsible for presenting reporting dashboard in the form of HTML page.
+    """
+    methods = ['GET']
+
+    @classmethod
+    def get_view_name(cls):
+        return 'dashboard'
+
+
+class APIDashboardView(AJAXMixin, AbstractDashboardView):  # pylint: disable=locally-disabled,too-many-ancestors
+    """
+    View responsible for presenting reporting dashboard in the form of JSON document.
+    """
+    methods = ['GET','POST']
+
+    @classmethod
+    def get_view_name(cls):
+        return 'apidashboard'
+
+    def process_response_context(self):
+        super().process_response_context()
+        # Prevent certain response context keys to appear in final response.
+        for key in ('items', 'quicksearch_list'):
+            try:
+                del self.response_context[key]
+            except KeyError:
+                pass
+        return self.response_context
+
+
 class DeleteView(HTMLMixin, SQLAlchemyMixin, ItemDeleteView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for deleting existing user accounts.
@@ -631,16 +656,16 @@ def get_blueprint():
     hbp = ReportsBlueprint(
         BLUEPRINT_NAME,
         __name__,
-        template_folder = 'templates',
-        url_prefix = '/{}'.format(BLUEPRINT_NAME)
+        template_folder = 'templates'
     )
 
-    hbp.register_view_class(SearchView,     '/search')
-    hbp.register_view_class(ShowView,       '/<int:item_id>/show')
-    hbp.register_view_class(UnauthShowView, '/<item_id>/unauth')
-    hbp.register_view_class(DataView,       '/data/<fileid>/<filetype>')
-    hbp.register_view_class(DashboardView,  '/dashboard')
-    hbp.register_view_class(DeleteView,     '/<int:item_id>/delete')
-    hbp.register_view_class(FeedbackView,   '/<item_id>/feedback')
+    hbp.register_view_class(SearchView,       '/{}/search'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(ShowView,         '/{}/<int:item_id>/show'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(UnauthShowView,   '/{}/<item_id>/unauth'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(DataView,         '/{}/data/<fileid>/<filetype>'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(DashboardView,    '/{}/dashboard'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(DeleteView,       '/{}/<int:item_id>/delete'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(FeedbackView,     '/{}/<item_id>/feedback'.format(BLUEPRINT_NAME))
+    hbp.register_view_class(APIDashboardView, '/api/{}/dashboard'.format(BLUEPRINT_NAME))
 
     return hbp
