@@ -137,13 +137,6 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
                 all()
             self.response_context.update(item_changelog = item_changelog)
 
-def _fill_in_timing_defaults(form):
-    for attr in sorted(mentat.const.REPORTING_TIMING_ATTRS.keys()):
-        if getattr(form, attr).data is None:
-            getattr(form, attr).data = mentat.const.REPORTING_INTERVALS[
-                mentat.const.REPORTING_TIMING_ATTRS[attr]
-            ]
-
 class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for creating new reporting settings.
@@ -201,9 +194,6 @@ class CreateView(HTMLMixin, SQLAlchemyMixin, ItemCreateView):  # pylint: disable
     def get_item_form():
         return CreateSettingsReportingForm()
 
-    def do_before_response(self, **kwargs):
-        _fill_in_timing_defaults(self.response_context['form'])
-
 
 class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
@@ -267,9 +257,6 @@ class UpdateView(HTMLMixin, SQLAlchemyMixin, ItemUpdateView):  # pylint: disable
     def get_item_form(item):
         return UpdateSettingsReportingForm(obj = item)
 
-    def do_before_response(self, **kwargs):
-        _fill_in_timing_defaults(self.response_context['form'])
-
 
 #-------------------------------------------------------------------------------
 
