@@ -56,9 +56,9 @@ AGGREGATIONS = (
     (mentat.stats.idea.ST_SKEY_PROTOCOLS,   {}, {"aggr_set": "protocol"}),
     (mentat.stats.idea.ST_SKEY_DETECTORS,   {}, {"aggr_set": "node_name"}),
     (mentat.stats.idea.ST_SKEY_DETECTORTPS, {}, {"aggr_set": "node_type"}),
-    (mentat.stats.idea.ST_SKEY_ABUSES,      {}, {"aggr_set": "cesnet_resolvedabuses"}),
-    (mentat.stats.idea.ST_SKEY_CLASSES,     {}, {"aggr_set": "cesnet_eventclass"}),
-    (mentat.stats.idea.ST_SKEY_SEVERITIES,  {}, {"aggr_set": "cesnet_eventseverity"}),
+    (mentat.stats.idea.ST_SKEY_ABUSES,      {}, {"aggr_set": "resolvedabuses"}),
+    (mentat.stats.idea.ST_SKEY_CLASSES,     {}, {"aggr_set": "eventclass"}),
+    (mentat.stats.idea.ST_SKEY_SEVERITIES,  {}, {"aggr_set": "eventseverity"}),
 )
 
 
@@ -466,8 +466,8 @@ class TimelineBlueprint(VialBlueprint):
     def register_app(self, app):
         app.menu_main.add_entry(
             'view',
-            'dashboards.{}'.format(BLUEPRINT_NAME),
-            position = 30,
+            BLUEPRINT_NAME,
+            position = 150,
             view = SearchView,
             resptitle = True
         )
