@@ -48,7 +48,7 @@ AODS_IP4 = 'ip4'
 AODS_IP6 = 'ip6'
 
 
-FA_ICONS = {
+ICONS = {
 
     #
     # General icons.
@@ -114,6 +114,9 @@ FA_ICONS = {
     #
     # Action icons.
     #
+    'action-sort':         '<i class="fas fa-fw fa-sort"></i>',
+    'action-sort-asc':     '<i class="fas fa-fw fa-sort-up"></i>',
+    'action-sort-desc':    '<i class="fas fa-fw fa-sort-down"></i>',
     'action-more':         '<i class="fas fa-fw fa-cubes"></i>',
     'action-search':       '<i class="fas fa-fw fa-search"></i>',
     'action-show':         '<i class="fas fa-fw fa-eye"></i>',
