@@ -86,13 +86,13 @@ def get_event_severities():
     """
     Return list of all available event severities.
     """
-    return _get_values('itemset-stat-severities.json', 'cesnet_eventseverity')
+    return _get_values('itemset-stat-severities.json', 'eventseverity')
 
 def get_event_classes():
     """
     Return list of all available event classes.
     """
-    return _get_values('itemset-stat-classes.json', 'cesnet_eventclass')
+    return _get_values('itemset-stat-classes.json', 'eventclass')
 
 def get_event_protocols():
     """
@@ -104,7 +104,7 @@ def get_event_inspection_errs():
     """
     Return list of all available event inspection errors.
     """
-    return _get_values('itemset-stat-inspectionerrors.json', 'cesnet_inspectionerrors')
+    return _get_values('itemset-stat-inspectionerrors.json', 'inspectionerrors')
 
 def db_settings(app):
     """
