@@ -71,6 +71,8 @@ DFLT_INTERVAL_RUNLOG = 60
 
 DFLT_QUEUE_SIZE_LIMIT = 5000
 """Default limit for number of messages in the queue."""
+DFLT_QUEUE_IN_PERMS = 0o775
+"""Default interval in seconds for checking the input queue for new messages."""
 DFLT_QUEUE_IN_CHECK_INTERVAL = 3
 """Default interval in seconds for checking the input queue for new messages."""
 DFLT_QUEUE_OUT_CHECK_INTERVAL = 10
@@ -120,6 +122,8 @@ CKEY_CORE_REPORTER_TEMPLATEVARS = 'template_vars'
 """Name of the configuration subkey key for ``template vars`` configuration in ``core reporter`` configurations."""
 CKEY_CORE_REPORTER_EVENTCLASSESDIR = 'event_classes_dir'
 """Name of the configuration subkey key for ``event classes dir`` configuration in ``core reporter`` configurations."""
+CKEY_CORE_REPORTER_FALLBACK = 'fallback'
+"""Name of the configuration subkey key for ``fallback`` configuration in ``core reporter`` configurations."""
 
 CKEY_CORE_INFORMANT = '__core__informant'
 """Name of the configuration key for ``core informant`` configurations."""
@@ -149,13 +153,6 @@ REPORTING_MODE_NONE    = tr_('none')
 
 REPORTING_MODES = (REPORTING_MODE_SUMMARY, REPORTING_MODE_EXTRA, REPORTING_MODE_BOTH, REPORTING_MODE_NONE)
 
-REPORTING_ATTACH_JSON = tr_('json')
-REPORTING_ATTACH_CSV  = tr_('csv')
-REPORTING_ATTACH_ALL  = tr_('all')
-REPORTING_ATTACH_NONE = tr_('none')
-
-REPORTING_ATTACHS = (REPORTING_ATTACH_JSON, REPORTING_ATTACH_CSV, REPORTING_ATTACH_ALL, REPORTING_ATTACH_NONE)
-
 REPORTING_TIMING_DEFAULT = tr_('default')
 REPORTING_TIMING_CUSTOM  = tr_('custom')
 
@@ -227,15 +224,12 @@ REPORTING_INTERVALS = {
 }
 
 DFLT_REPORTING_MODE          = REPORTING_MODE_SUMMARY
-DFLT_REPORTING_ATTACHMENTS   = REPORTING_ATTACH_JSON
 DFLT_REPORTING_TEMPLATE      = 'default'
 DFLT_REPORTING_LOCALE        = 'en'
 DFLT_REPORTING_TIMEZONE      = 'UTC'
 DFLT_REPORTING_TIMING        = REPORTING_TIMING_DEFAULT
 DFLT_REPORTING_MUTE          = False
 DFLT_REPORTING_REDIRECT      = False
-DFLT_REPORTING_COMPRESS      = False
-DFLT_REPORTING_MAXATTACHSIZE = 10485760
 
 REPORTING_INTERVALS_INV = {v: k for k, v in REPORTING_INTERVALS.items()}
 
@@ -245,14 +239,6 @@ REPORT_TYPES = (REPORT_TYPE_SUMMARY, REPORT_TYPE_EXTRA)
 
 REPORT_SEVERITIES = (EVENT_SEVERITY_LOW, EVENT_SEVERITY_MEDIUM, EVENT_SEVERITY_HIGH, EVENT_SEVERITY_CRITICAL)
 
-REPORT_ATTACHMENT_SIZES = {
-    20971520: '20 MB',
-    15728640: '15 MB',
-    10485760: '10 MB',
-    5242880: '5 MB',
-    1048576: '1 MB'
-}
-
 NAGIOS_PLUGIN_RC_OK       = 0
 NAGIOS_PLUGIN_RC_WARNING  = 1
 NAGIOS_PLUGIN_RC_CRITICAL = 2
