@@ -22,6 +22,7 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 
 import os
 import traceback
+import shutil
 
 #
 # Custom libraries.
@@ -75,6 +76,7 @@ class FilerDaemonComponent(pyzenkit.zendaemon.ZenDaemonComponent):  # pylint: di
 
         # Initialize internal variables
         self.queue_in_dir    = None
+        self.queue_in_perms  = None
         self.queue_out_dir   = None
         self.queue_out_limit = None
         self.queue_out_wait  = None
@@ -120,27 +122,18 @@ class FilerDaemonComponent(pyzenkit.zendaemon.ZenDaemonComponent):  # pylint: di
         Perform component setup.
         """
         self.queue_in_dir    = daemon.cc(daemon.CORE_FILEQUEUE).get(mentat.dirq.DirectoryQueue.CONFIG_DIR_QUEUE)
+        self.queue_in_perms  = daemon.cc(daemon.CORE_FILEQUEUE).get(mentat.dirq.DirectoryQueue.CONFIG_QUEUE_PERMS)
         self.queue_out_dir   = daemon.cc(daemon.CORE_FILEQUEUE).get(mentat.dirq.DirectoryQueue.CONFIG_DIR_NEXT_QUEUE)
         self.queue_out_limit = daemon.cc(daemon.CORE_FILEQUEUE).get(self.CONFIG_QUEUE_OUT_LIMIT)
         self.queue_out_wait  = daemon.cc(daemon.CORE_FILEQUEUE).get(self.CONFIG_QUEUE_OUT_WAIT)
 
-        # Attempt to create queue directories
-        if not os.path.isdir(self.queue_in_dir):
-            daemon.logger.debug(
-                "[STATUS] Component '{}': Preparing inbound message queue directory '{}'".format(
-                    self.cid,
-                    self.queue_in_dir
-                )
-            )
-            os.makedirs(self.queue_in_dir)
-        if self.queue_out_dir and not os.path.isdir(self.queue_out_dir):
-            daemon.logger.debug(
-                "[STATUS] Component '{}': Preparing outbound message queue directory '{}'".format(
-                    self.cid,
-                    self.queue_out_dir
-                )
-            )
-            os.makedirs(self.queue_out_dir)
+        # Make sure input queue directory exists
+        self._prepare_workdir(daemon, self.queue_in_dir, daemon.c(daemon.CONFIG_USER), daemon.c(daemon.CONFIG_GROUP), self.queue_in_perms)
+        self._check_workdir_writability(daemon, self.queue_in_dir)
+
+        # Make sure output queue directory is accessible and writeble
+        if self.queue_out_dir:
+            self._check_workdir_writability(daemon, self.queue_out_dir)
 
         self.dirq          = mentat.dirq.DirectoryQueue(**daemon.cc(daemon.CORE_FILEQUEUE))
         self.status        = self.STATUS_RUNNING
@@ -188,6 +181,38 @@ class FilerDaemonComponent(pyzenkit.zendaemon.ZenDaemonComponent):  # pylint: di
                 )
             )
 
+    def _prepare_workdir(self, daemon, dir_name, user = None, group = None, perms = None):
+        if not os.path.isdir(dir_name):
+            daemon.logger.info(
+                "[STATUS] Component '{}': Preparing work directory '{}' ({}:{},{})".format(
+                    self.cid, dir_name, str(user), str(group), str(oct(perms))
+                )
+            )
+            try:
+                os.makedirs(dir_name)
+                if perms:
+                    os.chmod(dir_name, perms)
+                if user or group:
+                    shutil.chown(dir_name, user = user[0], group = group[0])
+            except:
+                msg = "Unable to create work directory '{}' with 'UID:{},GID:{},PERMS:{}' as current effective user 'EUID:{},EGID:{}': '{}'".format(
+                    dir_name, str(user), str(group), str(oct(perms)), os.geteuid(), os.getegid(), traceback.format_exc()
+                )
+                daemon.logger.error("[STATUS] Component '{}': {}".format(self.cid, msg))
+                raise pyzenkit.zendaemon.ZenDaemonComponentException(msg)
+
+    def _check_workdir_writability(self, daemon, dir_name):
+        if not os.path.isdir(dir_name):
+            msg = "Work directory '{}' does not exist".format(dir_name)
+            daemon.logger.error("[STATUS] Component '{}': {}".format(self.cid, msg))
+            raise pyzenkit.zendaemon.ZenDaemonComponentException(msg)
+        if not os.access(dir_name, os.W_OK):
+            msg = "Work directory '{}' is not writable for current effective user 'EUID:{},EGID:{}'".format(
+                dir_name, os.geteuid(), os.getegid()
+            )
+            daemon.logger.error("[STATUS] Component '{}': {}".format(self.cid, msg))
+            raise pyzenkit.zendaemon.ZenDaemonComponentException(msg)
+
     #---------------------------------------------------------------------------
 
     def cbk_event_start(self, daemon, args):
