@@ -61,11 +61,6 @@ AG_REPORTING_MODE_SUMMARY = 'summary'
 AG_REPORTING_MODE_EXTRA   = 'extra'
 AG_REPORTING_MODE_BOTH    = 'both'
 
-AG_REPORTING_ATTACH_JSON = 'json'
-AG_REPORTING_ATTACH_CSV  = 'csv'
-AG_REPORTING_ATTACH_ALL  = 'all'
-AG_REPORTING_ATTACH_NONE = 'none'
-
 RE_TIMESTAMP = re.compile(r"^([0-9]{4})-([0-9]{2})-([0-9]{2})[Tt ]([0-9]{2}):([0-9]{2}):([0-9]{2})(?:\.([0-9]+))?([Zz]|(?:[+-][0-9]{2}:[0-9]{2}))$")
 
 
@@ -318,8 +313,11 @@ def t_network_record(val, source = None):
     record['first'] = record['nrobj'].low()
     record['last']  = record['nrobj'].high()
 
-    if 'netname' in val:
-        record['netname'] = val['netname']
+    if 'netnames' in val:
+        if isinstance(val['netnames'], list):
+            record['netname'] = ', '.join(val['netnames'])
+        else:
+            record['netname'] = val['netnames']
 
     if 'description' in val:
         if isinstance(val['description'], list):
@@ -336,14 +334,35 @@ def t_network_record(val, source = None):
     if 'source' in val:
         record['source'] = val['source']
     else:
-        record['source'] = source
+        if 'feed' in val:
+            record['source'] = source + '/' + val['feed']
+        else:
+            record['source'] = source
 
-    if 'resolved_abuses' in val:
-        record['resolved_abuses'] = val['resolved_abuses']
+    if 'abuse_group' in val:
+        record['abuse_group'] = val['abuse_group']
+        record['is_base'] = val.get('is_base', False)
+    elif 'resolved_abuses' in val:
+        for severity in 'fallback', 'low', 'medium', 'high', 'critical':
+            if severity in val['resolved_abuses']:
+                record['emails_{}'.format(severity)] = val['resolved_abuses'][severity]
+
+        # compute resulting abuse group from all emails
+        emails = []
+        for severity in 'emails_fallback', 'emails_low', 'emails_medium', 'emails_high', 'emails_critical':
+            if severity in record:
+                emails.extend(record[severity])
+        if emails:
+            record['abuse_group'] = ','.join(sorted(map(str.lower, list(set(emails)))))
+
+        record['is_base'] = val['is_base'] if 'is_base' in val else 'fallback' in val['resolved_abuses']
 
     if 'emails' in val:
         record['emails'] = val['emails']
 
+    if 'rank' in val:
+        record['rank'] = val['rank']
+
     if record['type'] == NR_TYPE_IPV4:
         return NetworkRecordIP4(record)
     return NetworkRecordIP6(record)
@@ -356,14 +375,6 @@ def t_reporting_mode(val):
         return str(val)
     raise ValueError("Invalid reporting mode '{:s}' for abuse group".format(val))
 
-def t_reporting_attach(val):
-    """
-    Convert/validate: Reporting attachment.
-    """
-    if str(val) in [AG_REPORTING_ATTACH_JSON, AG_REPORTING_ATTACH_CSV, AG_REPORTING_ATTACH_ALL, AG_REPORTING_ATTACH_NONE]:
-        return str(val)
-    raise ValueError("Invalid reporting attachment '{:s}' for abuse group".format(val))
-
 def t_reporting_filter(val):
     """
     Convert/validate: Reporting filter.
@@ -380,12 +391,6 @@ def t_filter_type(val):
         val = 'basic'
     return val
 
-def t_reporting_timing(val):
-    """
-    Convert/validate: Reporting timing.
-    """
-    return val
-
 def t_saved_query(val):
     """
     Convert/validate: Saved query.
@@ -425,9 +430,7 @@ types_internal = {
     'NetRecTypeIP6':    t_network_record_type_ip6,
     'NetworkRecordOld': t_network_record_old,
     'ReportingMode':    t_reporting_mode,
-    'ReportingAttach':  t_reporting_attach,
     'ReportingFilter':  t_reporting_filter,
-    'ReportingTiming':  t_reporting_timing,
     'FilterType':       t_filter_type,
     'SavedQuery':       t_saved_query
 }
@@ -484,9 +487,33 @@ def typedef_network_record_ip4(flavour, list_flavour, addon = None):
         'emails': {
             'type': list_flavour['String']
         },
+        'emails_fallback': {
+            'type': list_flavour['String']
+        },
+        'emails_low': {
+            'type': list_flavour['String']
+        },
+        'emails_medium': {
+            'type': list_flavour['String']
+        },
+        'emails_high': {
+            'type': list_flavour['String']
+        },
+        'emails_critical': {
+            'type': list_flavour['String']
+        },
         'resolved_abuses': {
             'type': list_flavour['String']
         },
+        'is_base': {
+            'type': flavour['Boolean']
+        },
+        'abuse_group': {
+            'type': flavour['String']
+        },
+        'rank': {
+            'type': flavour['Integer']
+        },
         '_resolved_abuses_chain': typedcols.Discard
     }
     if addon is not None:
@@ -549,9 +576,33 @@ def typedef_network_record_ip6(flavour, list_flavour, addon = None):
         'emails': {
             'type': list_flavour['String']
         },
+        'emails_fallback': {
+            'type': list_flavour['String']
+        },
+        'emails_low': {
+            'type': list_flavour['String']
+        },
+        'emails_medium': {
+            'type': list_flavour['String']
+        },
+        'emails_high': {
+            'type': list_flavour['String']
+        },
+        'emails_critical': {
+            'type': list_flavour['String']
+        },
         'resolved_abuses': {
             'type': list_flavour['String']
         },
+        'is_base': {
+            'type': flavour['Boolean']
+        },
+        'abuse_group': {
+            'type': flavour['String']
+        },
+        'rank': {
+            'type': flavour['Integer']
+        },
         '_resolved_abuses_chain': typedcols.Discard
     }
     if addon is not None:
@@ -674,12 +725,16 @@ def typedef_abuse_group(flavour, list_flavour, addon = None):
             'required': True,
             'default': AG_REPORTING_MODE_SUMMARY
         },
-        'rep_attach': {
-            'type': flavour['ReportingAttach'],
-            'required': True,
-            'default': AG_REPORTING_ATTACH_JSON
+        'rep_emails_low': {
+            'type': list_flavour['String']
         },
-        'rep_emails': {
+        'rep_emails_medium': {
+            'type': list_flavour['String']
+        },
+        'rep_emails_high': {
+            'type': list_flavour['String']
+        },
+        'rep_emails_critical': {
             'type': list_flavour['String']
         },
         'rep_filters': {
@@ -695,20 +750,6 @@ def typedef_abuse_group(flavour, list_flavour, addon = None):
             'required': True,
             'default': True
         },
-        'rep_compress': {
-            'type': flavour['Boolean'],
-            'required': True,
-            'default': False
-        },
-        'rep_timing_type': {
-            'type': flavour['String']
-        },
-        'rep_timing': {
-            'type': flavour['ReportingTiming']
-        },
-        'rep_template': {
-            'type': flavour['String']
-        },
         'query': {
             'type': list_flavour['SavedQuery']
         },
@@ -991,18 +1032,6 @@ def typedef_report(flavour, list_flavour, addon = None):
             'required': True,
             'default': time.time
         },
-        'attachment_file1': {
-            'type': flavour['String'],
-            'required': True
-        },
-        'attachment_file2': {
-            'type': flavour['String'],
-            'required': True
-        },
-        'cfg_attach': {
-            'type': flavour['String'],
-            'required': True
-        },
 
         'cnt_all': {
             'type': flavour['Integer'],
