@@ -68,8 +68,7 @@ from sqlalchemy.ext.compiler import compiles
 
 from werkzeug.security import generate_password_hash, check_password_hash
 
-from mentat.const import REPORTING_ATTACHS, REPORTING_MODES, REPORTING_TIMINGS,\
-    REPORTING_FILTERS, REPORTING_FILTER_BASIC,\
+from mentat.const import REPORTING_MODES, REPORTING_FILTERS, REPORTING_FILTER_BASIC,\
     REPORT_TYPES, REPORT_SEVERITIES
 
 
@@ -168,6 +167,18 @@ Association table representing user*group relation: group management.
 What users can manage what groups.
 """
 
+_asoc_groups_reports = sqlalchemy.Table(  # pylint: disable=locally-disabled,invalid-name
+    'asoc_groups_reports',
+    MODEL.metadata,
+    sqlalchemy.Column('group_id', sqlalchemy.ForeignKey('groups.id', onupdate = "CASCADE", ondelete = "CASCADE"), primary_key = True),
+    sqlalchemy.Column('report_id', sqlalchemy.ForeignKey('reports_events.id', onupdate = "CASCADE", ondelete = "CASCADE"), primary_key = True),
+)
+"""
+Association table representing group*report relation: ownership of report.
+
+What reports are linked to what groups (n:m relationship).
+"""
+
 
 class UserModel(MODEL):
     """
@@ -342,7 +353,6 @@ class GroupModel(MODEL):
     source      = sqlalchemy.Column(sqlalchemy.String(50), nullable = False)
     description = sqlalchemy.Column(sqlalchemy.String, nullable = False)
     enabled     = sqlalchemy.Column(sqlalchemy.Boolean, nullable = False, default = True)
-    managed     = sqlalchemy.Column(sqlalchemy.Boolean, nullable = False, default = False)
 
     members = sqlalchemy.orm.relationship('UserModel', secondary = _asoc_group_members, back_populates = 'memberships', order_by = 'UserModel.fullname')
     members_wanted = sqlalchemy.orm.relationship('UserModel', secondary = _asoc_group_members_wanted, back_populates = 'memberships_wanted', order_by = 'UserModel.fullname')
@@ -350,7 +360,7 @@ class GroupModel(MODEL):
 
     networks = sqlalchemy.orm.relationship('NetworkModel', back_populates = 'group', cascade = 'all, delete-orphan', order_by = 'NetworkModel.netname')
     filters  = sqlalchemy.orm.relationship('FilterModel', back_populates = 'group', cascade = 'all, delete-orphan', order_by = 'FilterModel.name')
-    reports  = sqlalchemy.orm.relationship('EventReportModel', back_populates = 'group', cascade = 'all, delete-orphan', order_by = 'EventReportModel.label')
+    reports  = sqlalchemy.orm.relationship('EventReportModel', secondary = _asoc_groups_reports, back_populates = 'groups', order_by = 'EventReportModel.label')
 
     settings_rep = sqlalchemy.orm.relationship('SettingsReportingModel', uselist = False, back_populates = 'group', cascade = 'all, delete-orphan')
 
@@ -398,7 +408,6 @@ class GroupModel(MODEL):
             'source':         str(self.source),
             'description':    str(self.description),
             'enabled':        bool(self.enabled),
-            'managed':        bool(self.managed),
             'members':        [(x.id, x.login) for x in self.members],
             'members_wanted': [(x.id, x.login) for x in self.members_wanted],
             'managers':       [(x.id, x.login) for x in self.managers],
@@ -438,6 +447,8 @@ class NetworkModel(MODEL):
     source      = sqlalchemy.Column(sqlalchemy.String(50), nullable = False)
     network     = sqlalchemy.Column(sqlalchemy.String, nullable = False)
     description = sqlalchemy.Column(sqlalchemy.String)
+    rank        = sqlalchemy.Column(sqlalchemy.Integer)
+    is_base     = sqlalchemy.Column(sqlalchemy.Boolean, nullable = False, default = False)
 
     def __repr__(self):
         return "<Network(netname='%s',network='%s')>" % (self.netname, self.network)
@@ -456,7 +467,9 @@ class NetworkModel(MODEL):
             'netname':     str(self.netname),
             'source':      str(self.source),
             'network':     str(self.network),
-            'description': str(self.description)
+            'description': str(self.description),
+            'rank':        int(self.rank) if self.rank else None,
+            'is_base':     bool(self.is_base)
         }
 
 def networkmodel_from_typeddict(structure, defaults = None):
@@ -472,6 +485,8 @@ def networkmodel_from_typeddict(structure, defaults = None):
     sqlobj.source      = structure.get('source')
     sqlobj.netname     = structure.get('netname', defaults.get('netname', '-- undisclosed --'))
     sqlobj.description = structure.get('description', defaults.get('description', None))
+    sqlobj.rank        = structure.get('rank', None)
+    sqlobj.is_base     = bool(structure.get('is_base', False))
 
     return sqlobj
 
@@ -588,32 +603,15 @@ class SettingsReportingModel(MODEL):  # pylint: disable=locally-disabled,too-few
     group_id = sqlalchemy.Column(sqlalchemy.Integer, sqlalchemy.ForeignKey('groups.id', onupdate = "CASCADE", ondelete = "CASCADE"), nullable = False)
     group = sqlalchemy.orm.relationship('GroupModel', back_populates = 'settings_rep')
 
-    emails      = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1))
-    mode        = sqlalchemy.Column(sqlalchemy.Enum(*REPORTING_MODES, name='reporting_modes'))
-    attachments = sqlalchemy.Column(sqlalchemy.Enum(*REPORTING_ATTACHS, name='reporting_attachments'))
-    template    = sqlalchemy.Column(sqlalchemy.String)
-    locale      = sqlalchemy.Column(sqlalchemy.String)
-    timezone    = sqlalchemy.Column(sqlalchemy.String)
+    emails_low = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1), default = [], nullable = False)
+    emails_medium = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1), default = [], nullable = False)
+    emails_high = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1), default = [], nullable = False)
+    emails_critical = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1), default = [], nullable = False)
+    mode = sqlalchemy.Column(sqlalchemy.Enum(*REPORTING_MODES, name='reporting_modes'))
+    locale = sqlalchemy.Column(sqlalchemy.String)
+    timezone = sqlalchemy.Column(sqlalchemy.String)
 
-    timing        = sqlalchemy.Column(sqlalchemy.Enum(*REPORTING_TIMINGS, name='timing_types'))
-    timing_per_lo = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_per_md = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_per_hi = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_per_cr = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_thr_lo = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_thr_md = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_thr_hi = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_thr_cr = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_rel_lo = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_rel_md = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_rel_hi = sqlalchemy.Column(sqlalchemy.Integer)
-    timing_rel_cr = sqlalchemy.Column(sqlalchemy.Integer)
-
-    mute     = sqlalchemy.Column(sqlalchemy.Boolean)
     redirect = sqlalchemy.Column(sqlalchemy.Boolean)
-    compress = sqlalchemy.Column(sqlalchemy.Boolean)
-
-    max_attachment_size = sqlalchemy.Column(sqlalchemy.Integer)
 
     def __repr__(self):
         return "<SettingsReporting(id='%d',group_id='%d')>" % (int(self.id), int(self.group_id))
@@ -623,33 +621,17 @@ class SettingsReportingModel(MODEL):  # pylint: disable=locally-disabled,too-few
         *Interface implementation:* Implementation of :py:func:`mentat.datatype.sqldb.MODEL.to_dict` method.
         """
         return {
-            'id':            int(self.id),
-            'createtime':    str(self.createtime),
-            'group':         str(self.group),
-            'emails':        [str(x) for x in self.emails] if self.emails is not None else None,
-            'mode':          str(self.mode) if self.mode is not None else None,
-            'attachments':   str(self.attachments) if self.attachments is not None else None,
-            'template':      str(self.template) if self.template is not None else None,
-            'locale':        str(self.locale) if self.locale is not None else None,
-            'timezone':      str(self.timezone) if self.timezone is not None else None,
-            'timing':        str(self.timing) if self.timing is not None else None,
-            'timing_per_lo': int(self.timing_per_lo) if self.timing_per_lo is not None else None,
-            'timing_per_md': int(self.timing_per_md) if self.timing_per_md is not None else None,
-            'timing_per_hi': int(self.timing_per_hi) if self.timing_per_hi is not None else None,
-            'timing_per_cr': int(self.timing_per_cr) if self.timing_per_cr is not None else None,
-            'timing_thr_lo': int(self.timing_thr_lo) if self.timing_thr_lo is not None else None,
-            'timing_thr_md': int(self.timing_thr_md) if self.timing_thr_md is not None else None,
-            'timing_thr_hi': int(self.timing_thr_hi) if self.timing_thr_hi is not None else None,
-            'timing_thr_cr': int(self.timing_thr_cr) if self.timing_thr_cr is not None else None,
-            'timing_rel_lo': int(self.timing_rel_lo) if self.timing_rel_lo is not None else None,
-            'timing_rel_md': int(self.timing_rel_md) if self.timing_rel_md is not None else None,
-            'timing_rel_hi': int(self.timing_rel_hi) if self.timing_rel_hi is not None else None,
-            'timing_rel_cr': int(self.timing_rel_cr) if self.timing_rel_cr is not None else None,
-            'mute':          bool(self.mute) if self.mute is not None else None,
-            'redirect':      bool(self.redirect) if self.redirect is not None else None,
-            'compress':      bool(self.compress) if self.compress is not None else None,
-
-            'max_attachment_size': int(self.max_attachment_size) if self.max_attachment_size is not None else None
+            'id':                 int(self.id),
+            'createtime':         str(self.createtime),
+            'group':              str(self.group),
+            'emails_low':         [str(x) for x in self.emails_low],
+            'emails_medium':      [str(x) for x in self.emails_medium],
+            'emails_high':        [str(x) for x in self.emails_high],
+            'emails_critical':    [str(x) for x in self.emails_critical],
+            'mode':               str(self.mode) if self.mode is not None else None,
+            'locale':             str(self.locale) if self.locale is not None else None,
+            'timezone':           str(self.timezone) if self.timezone is not None else None,
+            'redirect':           bool(self.redirect) if self.redirect is not None else None
         }
 
 def setrepmodel_from_typeddict(structure, defaults = None):
@@ -661,13 +643,12 @@ def setrepmodel_from_typeddict(structure, defaults = None):
         defaults = {}
 
     sqlobj = SettingsReportingModel()
-    sqlobj.emails      = structure.get('rep_emails', None)
-    sqlobj.mode        = structure.get('rep_mode', None)
-    sqlobj.attachments = structure.get('rep_attach', None)
-    sqlobj.mute        = structure.get('rep_mute', None)
-    sqlobj.redirect    = structure.get('rep_redirect', None)
-    sqlobj.compress    = structure.get('rep_compress', None)
-    sqlobj.timing      = structure.get('rep_timing_type', None)
+    sqlobj.emails_low         = structure.get('rep_emails_low', [])
+    sqlobj.emails_medium      = structure.get('rep_emails_medium', [])
+    sqlobj.emails_high        = structure.get('rep_emails_high', [])
+    sqlobj.emails_critical    = structure.get('rep_emails_critical', [])
+    sqlobj.mode               = structure.get('rep_mode', None)
+    sqlobj.redirect           = structure.get('rep_redirect', None)
 
     if sqlobj.emails and '@' not in sqlobj.emails[0]:
         sqlobj.emails = [''.join(sqlobj.emails)]
@@ -770,8 +751,7 @@ class EventReportModel(MODEL):
     __tablename__ = 'reports_events'
 
     #group_name = sqlalchemy.Column(sqlalchemy.String, nullable = False, index = True)
-    group_id  = sqlalchemy.Column(sqlalchemy.Integer, sqlalchemy.ForeignKey('groups.id', onupdate = "CASCADE", ondelete = "CASCADE"), nullable = False)
-    group     = sqlalchemy.orm.relationship('GroupModel', back_populates = 'reports')
+    groups    = sqlalchemy.orm.relationship('GroupModel', secondary = _asoc_groups_reports, back_populates = 'reports')
 
     parent_id = sqlalchemy.Column(sqlalchemy.Integer, sqlalchemy.ForeignKey('reports_events.id'))
     children  = sqlalchemy.orm.relationship('EventReportModel', backref = sqlalchemy.orm.backref('parent', remote_side='EventReportModel.id'))
@@ -805,7 +785,7 @@ class EventReportModel(MODEL):
     # Number of relapsed events.
     evcount_rlp     = sqlalchemy.Column(sqlalchemy.Integer)
 
-    mail_to  = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1))
+    mail_to  = sqlalchemy.Column(sqlalchemy.dialects.postgresql.ARRAY(sqlalchemy.String, dimensions = 1), default = [], nullable = False)
     mail_dt  = sqlalchemy.Column(sqlalchemy.DateTime)
     mail_res = sqlalchemy.Column(sqlalchemy.String)
 
@@ -826,7 +806,7 @@ class EventReportModel(MODEL):
         return {
             'id':              int(self.id),
             'createtime':      str(self.createtime),
-            'group':           str(self.group),
+            'groups':          [str(group) for group in self.groups],
             'parent':          str(self.parent),
             'label':           str(self.label),
             'severity':        str(self.severity),
@@ -876,7 +856,6 @@ class EventReportModel(MODEL):
         )
         return self.label
 
-
 class ItemChangeLogModel(MODEL):
     """
     Class representing item changelog records within the SQL database mapped to
