@@ -298,10 +298,14 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
 
         group1 = GroupModel(name = 'abuse@cesnet.cz',  source = 'manual', description = 'CESNET, z.s.p.o.')
 
-        network1 = NetworkModel(group = group1, netname = 'NET1', source = 'manual', network = '192.168.0.0/24', description = 'Descr.')  # pylint: disable=locally-disabled,unused-variable
-        network2 = NetworkModel(group = group1, netname = 'NET2', source = 'manual', network = '10.0.0.0/8')  # pylint: disable=locally-disabled,unused-variable
-        network3 = NetworkModel(group = group1, netname = 'NET3', source = 'manual', network = '::1/128')  # pylint: disable=locally-disabled,unused-variable
-        network4 = NetworkModel(group = group1, netname = 'NET4', source = 'manual', network = '2001:ff::/64')  # pylint: disable=locally-disabled,unused-variable
+        network1 = NetworkModel(group = group1, netname = 'NET1', source = 'manual', network = '192.168.0.0/24', description = 'Descr.')
+        self.assertIsNotNone(network1)
+        network2 = NetworkModel(group = group1, netname = 'NET2', source = 'manual', network = '10.0.0.0/8')
+        self.assertIsNotNone(network2)
+        network3 = NetworkModel(group = group1, netname = 'NET3', source = 'manual', network = '::1/128')
+        self.assertIsNotNone(network3)
+        network4 = NetworkModel(group = group1, netname = 'NET4', source = 'manual', network = '2001:ff::/64')
+        self.assertIsNotNone(network4)
 
         self.session.add(group1)
         self.session.commit()
@@ -360,8 +364,10 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
 
         group1 = GroupModel(name = 'abuse@cesnet.cz',  source = 'manual', description = 'CESNET, z.s.p.o.')
 
-        filter1 = FilterModel(group = group1, name = 'FLT1', type = 'basic', filter = 'Source.IP4 == 127.0.0.1', description = 'DESC1')  # pylint: disable=locally-disabled,unused-variable
-        filter2 = FilterModel(group = group1, name = 'FLT2', type = 'advanced', filter = 'Source.IP4 == 127.0.0.2', description = 'DESC2')  # pylint: disable=locally-disabled,unused-variable
+        filter1 = FilterModel(group = group1, name = 'FLT1', type = 'basic', filter = 'Source.IP4 == 127.0.0.1', description = 'DESC1')
+        self.assertIsNotNone(filter1)
+        filter2 = FilterModel(group = group1, name = 'FLT2', type = 'advanced', filter = 'Source.IP4 == 127.0.0.2', description = 'DESC2')
+        self.assertIsNotNone(filter2)
 
         self.session.add(group1)
         self.session.commit()
@@ -420,7 +426,7 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
         group1 = GroupModel(name = 'abuse@cesnet.cz',  source = 'manual', description = 'CESNET, z.s.p.o.')
 
         settings1 = SettingsReportingModel(group = group1)  # pylint: disable=locally-disabled,unused-variable
-        settings2 = SettingsReportingModel(emails = ['abuse@domain'], redirect = True)  # pylint: disable=locally-disabled,unused-variable
+        settings2 = SettingsReportingModel(emails_low = ['abuse@domain'], redirect = True)  # pylint: disable=locally-disabled,unused-variable
 
         group2 = GroupModel(name = 'abuse@domain.org', source = 'manual', description = 'Domain Organization', settings_rep = settings2)
 
@@ -433,41 +439,21 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
         self.assertEqual(result.settings_rep.__class__.__name__, 'SettingsReportingModel')
         self.assertTrue(result.settings_rep.to_dict())
         self.assertEqual(result.settings_rep.mode, None)
-        self.assertEqual(result.settings_rep.attachments, None)
 
         result = self.session.query(GroupModel).filter(GroupModel.name == 'abuse@domain.org').one()
         self.assertEqual(repr(result.settings_rep), "<SettingsReporting(id='2',group_id='2')>")
         self.assertEqual(result.settings_rep.mode, None)
-        self.assertEqual(result.settings_rep.attachments, None)
         self.assertTrue(result.id)
         self.assertTrue(result.createtime)
         self.assertEqual(result.settings_rep.mode, None)
-        self.assertEqual(result.settings_rep.attachments, None)
-        self.assertEqual(result.settings_rep.emails, ['abuse@domain'])
-        self.assertEqual(result.settings_rep.mute, None)
+        self.assertEqual(result.settings_rep.emails_low, ['abuse@domain'])
         self.assertEqual(result.settings_rep.redirect, True)
-        self.assertEqual(result.settings_rep.compress, None)
-        self.assertEqual(result.settings_rep.template, None)
         self.assertEqual(result.settings_rep.locale, None)
         self.assertEqual(result.settings_rep.timezone, None)
-        self.assertEqual(result.settings_rep.timing, None)
-        self.assertEqual(result.settings_rep.timing_per_lo, None)
-        self.assertEqual(result.settings_rep.timing_per_md, None)
-        self.assertEqual(result.settings_rep.timing_per_hi, None)
-        self.assertEqual(result.settings_rep.timing_per_cr, None)
-        self.assertEqual(result.settings_rep.timing_thr_lo, None)
-        self.assertEqual(result.settings_rep.timing_thr_md, None)
-        self.assertEqual(result.settings_rep.timing_thr_hi, None)
-        self.assertEqual(result.settings_rep.timing_thr_cr, None)
-        self.assertEqual(result.settings_rep.timing_rel_lo, None)
-        self.assertEqual(result.settings_rep.timing_rel_md, None)
-        self.assertEqual(result.settings_rep.timing_rel_hi, None)
-        self.assertEqual(result.settings_rep.timing_rel_cr, None)
 
         # Attempt to change something and make diff.
         settings_json_a = settings1.to_json()
         settings1.mode = 'extra'
-        settings1.mute = True
         self.session.commit()
         settings_json_b = settings1.to_json()
         self.assertTrue(jsondiff(settings_json_a, settings_json_b))
@@ -531,7 +517,7 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
         delta    = dt_to - dt_from
 
         report = EventReportModel(
-            group          = group,
+            groups         = [group],
             label          = 'REPORTID',
             severity       = 'low',
             type           = 'summary',
@@ -572,11 +558,13 @@ class TestMentatDatatypeSqldb(unittest.TestCase):
         self.assertEqual(result.__class__.__name__, 'EventReportModel')
         self.assertTrue(result.to_dict())
 
+        #TODO: test deletion of report after all related groups were deleted
         # Attempt to delete parent object.
-        self.session.delete(group)
-        self.session.commit()
-        result = self.session.query(EventReportModel).count()
-        self.assertEqual(result, 0)
+        #self.session.delete(group)
+        #self.session.commit()
+        #result = self.session.query(EventReportModel).count()
+        #self.assertEqual(result, 0)
+
 
     def test_09_changelog_model(self):
         """
