@@ -45,17 +45,19 @@ import typedcols
 import idea.base
 import idea.lite
 
+import ipranges
+
 import pynspect.jpath
 import pynspect.rules
 import pynspect.compilers
 
 
-def cesnet_dict_typedef(flavour, list_flavour, errors_list, abuses_list, addon=None):
+def mentat_dict_typedef(flavour, list_flavour, errors_list, abuses_list, addon=None):
     """
     Typedef generator helper for easy usage of custom definitions at
     multiple places.
     """
-    cesnet_def = {
+    mentat_def = {
         "InspectionErrors": {
             "description": "List of event pecularities found during inspection",
             "type": errors_list
@@ -94,17 +96,17 @@ def cesnet_dict_typedef(flavour, list_flavour, errors_list, abuses_list, addon=N
         }
     }
     if addon is not None:
-        cesnet_def.update(addon)
-    return cesnet_def
+        mentat_def.update(addon)
+    return mentat_def
 
 
-class CESNETDict(typedcols.TypedDict):  # pylint: disable=locally-disabled,too-many-ancestors
+class MentatDict(typedcols.TypedDict):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     This type definition represents a custom subdictionary under key
-    *_CESNET* in message root dictionary.
+    *_Mentat*/*_CESNET* in message root dictionary.
     """
     allow_unknown = True
-    typedef = cesnet_dict_typedef(
+    typedef = mentat_dict_typedef(
         idea.lite.idea_types,
         idea.lite.idea_lists,
         typedcols.typed_list("InspectionErrorsList", str),
@@ -112,7 +114,7 @@ class CESNETDict(typedcols.TypedDict):  # pylint: disable=locally-disabled,too-m
     )
 
 
-def internal_base_addon_typedef(flavour, list_flavour, cesnet_dict, addon=None):  # pylint: disable=locally-disabled,unused-argument
+def internal_base_addon_typedef(flavour, list_flavour, mentat_dict, addon=None):  # pylint: disable=locally-disabled,unused-argument
     """
     Typedef generator helper for easy usage of custom definitions at
     multiple places.
@@ -126,9 +128,13 @@ def internal_base_addon_typedef(flavour, list_flavour, cesnet_dict, addon=None):
             "description": "CESNET specific timestamp as native Unix timestamp",
             "type": flavour["Integer"]
         },
+        "_Mentat": {
+            "description": "Custom CESNET/Mentat abominations to IDEA definition",
+            "type": mentat_dict
+        },
         "_CESNET": {
             "description": "Custom CESNET/Mentat abominations to IDEA definition",
-            "type": cesnet_dict
+            "type": mentat_dict
         }
     }
     if addon is not None:
@@ -157,7 +163,7 @@ class Idea(idea.lite.Idea):  # pylint: disable=locally-disabled,too-many-ancesto
         internal_base_addon_typedef(
             idea.lite.idea_types,
             idea.lite.idea_lists,
-            CESNETDict
+            MentatDict
         )
     )
 
@@ -200,41 +206,51 @@ class Idea(idea.lite.Idea):  # pylint: disable=locally-disabled,too-many-ancesto
         """
         return self['DetectTime']
 
+    def get_custom_key(self):
+        """
+        Convenience method for returning the correct custom key.
+
+        :return: The value of _Mentat if present, otherwise the value of _CESNET if present.
+        If neither of those keys exist then empty dictionary is returned.
+        :rtype: mentat_dict
+        """
+        return self.get('_Mentat') if '_Mentat' in self else self.get('_CESNET', {})
+
     def get_storage_time(self):
         """
         Convenience method for returning message storage time.
 
-        :return: Value of message attribute ``idea['_CESNET']['StorageTime']``.
+        :return: Value of message attribute ``idea['_Mentat'/'_CESNET']['StorageTime']``.
         :rtype: datetime.datetime
         """
-        return self.get('_CESNET', {}).get('StorageTime', None)
+        return self.get_custom_key().get('StorageTime', None)
 
     def get_class(self):
         """
         Convenience method for returning message event class.
 
-        :return: Value of message attribute ``idea['_CESNET']['EventClass']``.
+        :return: Value of message attribute ``idea['_Mentat'/'_CESNET']['EventClass']``.
         :rtype: str
         """
-        return self.get('_CESNET', {}).get('EventClass', None)
+        return self.get_custom_key().get('EventClass', None)
 
     def get_severity(self):
         """
         Convenience method for returning message event severity.
 
-        :return: Value of message attribute ``idea['_CESNET']['EventSeverity']``.
+        :return: Value of message attribute ``idea['_Mentat'/'_CESNET']['EventSeverity']``.
         :rtype: str
         """
-        return self.get('_CESNET', {}).get('EventSeverity', None)
+        return self.get_custom_key().get('EventSeverity', None)
 
     def get_abuses(self):
         """
         Convenience method for returning list of all resolved abuses.
 
-        :return: Value of message attribute ``idea['_CESNET']['ResolvedAbuses']``.
+        :return: Value of message attribute ``idea['_Mentat'/'_CESNET']['ResolvedAbuses']``.
         :rtype: list of strings
         """
-        return list(self.get('_CESNET', {}).get('ResolvedAbuses', list()))
+        return list(self.get_custom_key().get('ResolvedAbuses', list()))
 
     def get_categories(self):
         """
@@ -261,7 +277,43 @@ class Idea(idea.lite.Idea):  # pylint: disable=locally-disabled,too-many-ancesto
         :return: Value of message attribute ``idea['Node']['Name']``.
         :rtype: list of strings
         """
-        return [node['Name'] for node in self.get('Node', [])]
+        return [name for name in (node.get('Name', None) for node in self.get('Node', [])) if name]
+
+    @staticmethod
+    def get_ranges(addresses, rngcls, ipcls):
+        """
+        Helper function for making ranges of IP addresses.
+
+        :param list addrs: List of single addresses, nets or ranges of IP4 or IP6 addresses.
+        :param class rngcls: The class of returned list (either IP4Range or IP6Range).
+        :param class ipcls: The class of single IP address (either IP4 or IP6).
+        :return: The list of ranges of IP addresses.
+        :rtype: list of ``rngcls`` objects
+        """
+        addrs = sorted(addresses, reverse = True, key = lambda ip: ip.high())
+
+        result = []
+        prev = None
+        ipmin = None
+        ipmax = None
+
+        for curr in addrs:
+            if not prev:
+                ipmin = curr.low()
+                ipmax = curr.high()
+            else:
+                if curr.high() + 1 >= ipmin:
+                    ipmin = min(curr.low(), ipmin)
+                else:
+                    result.append(rngcls((ipmin, ipmax)) if ipmin != ipmax else ipcls(ipmin))
+                    ipmin = curr.low()
+                    ipmax = curr.high()
+            prev = curr
+
+        if ipmin and ipmax:
+            result.append(rngcls((ipmin, ipmax)) if ipmin != ipmax else ipcls(ipmin))
+
+        return result
 
     def get_addresses(self, node, get_v4 = True, get_v6 = True):
         """
@@ -275,12 +327,19 @@ class Idea(idea.lite.Idea):  # pylint: disable=locally-disabled,too-many-ancesto
         :rtype: list of ipranges
         """
         result = []
+        ip4s = []
+        ip6s = []
+
         if node in self:
             for src in self[node]:
                 if get_v4 and 'IP4' in src:
-                    result.extend(list(src['IP4']))
+                    ip4s.extend(list(src['IP4']))
                 if get_v6 and 'IP6' in src:
-                    result.extend(list(src['IP6']))
+                    ip6s.extend(list(src['IP6']))
+
+            result.extend(self.get_ranges(ip4s, ipranges.IP4Range, ipranges.IP4))
+            result.extend(self.get_ranges(ip6s, ipranges.IP6Range, ipranges.IP6))
+
         return result
 
     def get_ports(self, node):
@@ -338,24 +397,33 @@ class Idea(idea.lite.Idea):  # pylint: disable=locally-disabled,too-many-ancesto
         """
         Convenience method for returning list of all resolved source countries.
 
-        :return: Value of message attribute ``idea['_CESNET']['SourceResolvedCountry']``.
+        :return: Value of message attribute ``idea['_Mentat'/'_CESNET']['SourceResolvedCountry']``.
         :rtype: list of strings
         """
         return list(
-            self.get('_CESNET', {}).get('SourceResolvedCountry', [])
+            self.get_custom_key().get('SourceResolvedCountry', [])
         )
 
     def get_asns_src(self):
         """
         Convenience method for returning list of all resolved source ASNs.
 
-        :return: Value of message attribute ``idea['_CESNET']['SourceResolvedASN']``.
+        :return: Value of message attribute ``idea['_Mentat'/'_CESNET']['SourceResolvedASN']``.
         :rtype: list of strings
         """
         return list(
-            self.get('_CESNET', {}).get('SourceResolvedASN', [])
+            self.get_custom_key().get('SourceResolvedASN', [])
         )
 
+    def get_inspection_errors(self):
+        """
+        Convenience method for returning a list of inspection errors.
+
+        :return: List of values of ``idea['_Mentat']['InspectionErrors']``.
+        :rtype: list
+        """
+        return self.get_jpath_values('_Mentat.InspectionErrors' if '_Mentat' in self else '_CESNET.InspectionErrors')
+
     def get_jpath_value(self, jpath):
         """
         Return single (first in case o a list) value on given JPath within the
@@ -433,20 +501,20 @@ class IdeaGhost(Idea):
                     node['Type'] = list(record.node_type)
                 idea_raw.setdefault('Node', []).append(node)
 
-        if record.cesnet_resolvedabuses:
-            idea_raw.setdefault('_CESNET', {})['ResolvedAbuses'] = list(record.cesnet_resolvedabuses)
-        if record.cesnet_storagetime:
-            idea_raw.setdefault('_CESNET', {})['StorageTime'] = record.cesnet_storagetime
-        if record.cesnet_eventclass:
-            idea_raw.setdefault('_CESNET', {})['EventClass'] = record.cesnet_eventclass
-        if record.cesnet_eventseverity:
-            idea_raw.setdefault('_CESNET', {})['EventSeverity'] = record.cesnet_eventseverity
-        if record.cesnet_inspectionerrors:
-            idea_raw.setdefault('_CESNET', {})['InspectionErrors'] = list(record.cesnet_inspectionerrors)
+        if record.resolvedabuses:
+            idea_raw.setdefault('_Mentat', {})['ResolvedAbuses'] = list(record.resolvedabuses)
+        if record.storagetime:
+            idea_raw.setdefault('_Mentat', {})['StorageTime'] = record.storagetime
+        if record.eventclass:
+            idea_raw.setdefault('_Mentat', {})['EventClass'] = record.eventclass
+        if record.eventseverity:
+            idea_raw.setdefault('_Mentat', {})['EventSeverity'] = record.eventseverity
+        if record.inspectionerrors:
+            idea_raw.setdefault('_Mentat', {})['InspectionErrors'] = list(record.inspectionerrors)
 
         try:
             return cls(idea_raw)
-        except Exception as exc:
+        except Exception:
             print("Record:")
             pprint.pprint(record)
             print("IDEA raw:")
@@ -466,7 +534,7 @@ class IDEAFilterCompiler(pynspect.compilers.IDEAFilterCompiler):
         super(IDEAFilterCompiler, self).__init__()
 
         self.register_variable_compilation(
-            '_CESNET.StorageTime',
+            '_Mentat.StorageTime',
             pynspect.compilers.compile_timeoper,
             pynspect.rules.ListRule
         )
