@@ -54,7 +54,7 @@ class TestMentatIdeaInternal(unittest.TestCase):
         'Source': [
             {
                 'Type': ['Phishing'],
-                'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.10/25', '192.168.1.1'],
+                'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25', '192.168.1.1', '192.168.1.2', '192.168.1.4'],
                 'IP6': ['2001:db8::ff00:42:0/112','2001:db8::ff00:42:50'],
                 'Hostname': ['example.com'],
                 'URL': ['http://example.com/cgi-bin/killemall'],
@@ -102,7 +102,7 @@ class TestMentatIdeaInternal(unittest.TestCase):
                 'AggrWin': '00:05:00'
             }
         ],
-        '_CESNET' : {
+        '_Mentat' : {
             'StorageTime': '2017-04-05T10:21:39Z',
             'EventTemplate': 'sserv-012',
             'ResolvedAbuses': ['abuse@cesnet.cz'],
@@ -145,7 +145,7 @@ class TestMentatIdeaInternal(unittest.TestCase):
                 'Type': ['Connection','Honeypot','Recon']
             }
         ],
-        '_CESNET': {
+        '_Mentat': {
             'StorageTime': '2016-06-21T14:00:07Z'
         }
     }
@@ -237,15 +237,14 @@ class TestMentatIdeaInternal(unittest.TestCase):
         self.assertEqual(idea_internal_1.get_description(), 'Synthetic example')
         self.assertEqual(idea_internal_1.get_detectors(), ['org.example.kippo_honey'])
         self.assertEqual(idea_internal_1.get_addresses('Source'), [
-            ipranges.IP4Range('192.168.0.2-192.168.0.5'),
-            ipranges.IP4Net('192.168.0.10/25'),
-            ipranges.IP4('192.168.1.1'),
-            ipranges.IP6Net('2001:db8::ff00:42:0/112'),
-            ipranges.IP6('2001:db8::ff00:42:50')
+            ipranges.IP4('192.168.1.4'),
+            ipranges.IP4Range('192.168.1.1-192.168.1.2'),
+            ipranges.IP4Range('192.168.0.0-192.168.0.127'),
+            ipranges.IP6Range('2001:db8::ff00:42:0-2001:db8::ff00:42:ffff')
         ])
         self.assertEqual(idea_internal_1.get_addresses('Target'), [
-            ipranges.IP6Net('2001:ffff::ff00:42:0/112'),
-            ipranges.IP4Net('10.2.2.0/24')
+            ipranges.IP4Range('10.2.2.0-10.2.2.255'),
+            ipranges.IP6Range('2001:ffff::ff00:42:0-2001:ffff::ff00:42:ffff')
         ])
         self.assertEqual(idea_internal_1.get_ports('Source'), [])
         self.assertEqual(idea_internal_1.get_ports('Target'), [22, 25, 443])
@@ -272,6 +271,46 @@ class TestMentatIdeaInternal(unittest.TestCase):
         new  = json.dumps(idea_internal_2, indent=4, sort_keys=True, default=idea_internal_2.json_default)
         self.assertEqual(orig, new, "\n".join([l for l in difflib.context_diff(orig.split("\n"), new.split("\n"))]))
 
+    def test_05_get_ranges(self):
+        """
+        Perform tests of get_ranges function.
+        """
+        self.maxDiff = None
+
+        self.assertEqual(mentat.idea.internal.Idea.get_ranges([], ipranges.IP4Range, ipranges.IP4), [])
+        self.assertEqual(mentat.idea.internal.Idea.get_ranges([], ipranges.IP6Range, ipranges.IP4), [])
+        self.assertEqual(mentat.idea.internal.Idea.get_ranges([
+            ipranges.IP4('192.168.0.2'),
+            ipranges.IP4('192.168.0.3'),
+            ipranges.IP4('192.168.0.4'),
+            ipranges.IP4('192.168.0.5')],
+            ipranges.IP4Range, ipranges.IP4),
+            [ipranges.IP4Range((ipranges.IP4('192.168.0.2'), ipranges.IP4('192.168.0.5')))])
+        self.assertEqual(mentat.idea.internal.Idea.get_ranges([
+            ipranges.IP4('192.168.0.3'),
+            ipranges.IP4('192.168.0.5'),
+            ipranges.IP4('192.168.1.19'),
+            ipranges.IP4('192.168.1.20')],
+            ipranges.IP4Range, ipranges.IP4),[
+            ipranges.IP4Range((ipranges.IP4('192.168.1.19'), ipranges.IP4('192.168.1.20'))),
+            ipranges.IP4('192.168.0.5'),
+            ipranges.IP4('192.168.0.3')])
+        self.assertEqual(mentat.idea.internal.Idea.get_ranges([
+            ipranges.IP4('192.168.0.2'),
+            ipranges.IP4('192.168.0.5'),
+            ipranges.IP4('192.168.0.7')],
+            ipranges.IP4Range, ipranges.IP4), [
+            ipranges.IP4('192.168.0.7'),
+            ipranges.IP4('192.168.0.5'),
+            ipranges.IP4('192.168.0.2')])
+
+        self.assertEqual(mentat.idea.internal.Idea.get_ranges([
+            ipranges.IP6('2001:db8::ff00:42:50'),
+            ipranges.IP6('2001:0db8::ff00:42:51'),
+            ipranges.IP6('2001:db8::ff00:42:0052'),
+            ipranges.IP6('2001:0db8::ff00:0042:0053')],
+            ipranges.IP6Range, ipranges.IP6),
+            [ipranges.IP6Range((ipranges.IP6('2001:db8::ff00:42:50'), ipranges.IP6('2001:db8::ff00:42:53')))])
 
 class TestIDEAFilterCompiler(unittest.TestCase):
     """
@@ -380,10 +419,10 @@ class TestIDEAFilterCompiler(unittest.TestCase):
         res = self.cpl.compile(rule)
         self.assertEqual(repr(res), "COMPBINOP(VARIABLE('WinEndTime') OP_EQ DATETIME(datetime.datetime(2016, 6, 21, 13, 8, 27)))")
 
-        rule = self.psr.parse('(_CESNET.StorageTime == "2016-06-21T13:08:27Z")')
-        self.assertEqual(repr(rule), "COMPBINOP(VARIABLE('_CESNET.StorageTime') OP_EQ CONSTANT('2016-06-21T13:08:27Z'))")
+        rule = self.psr.parse('(_Mentat.StorageTime == "2016-06-21T13:08:27Z")')
+        self.assertEqual(repr(rule), "COMPBINOP(VARIABLE('_Mentat.StorageTime') OP_EQ CONSTANT('2016-06-21T13:08:27Z'))")
         res = self.cpl.compile(rule)
-        self.assertEqual(repr(res), "COMPBINOP(VARIABLE('_CESNET.StorageTime') OP_EQ DATETIME(datetime.datetime(2016, 6, 21, 13, 8, 27)))")
+        self.assertEqual(repr(res), "COMPBINOP(VARIABLE('_Mentat.StorageTime') OP_EQ DATETIME(datetime.datetime(2016, 6, 21, 13, 8, 27)))")
 
     def test_03_idea_ip_compilations(self):
         """
