@@ -62,6 +62,11 @@ Custom command line options
 
     *Type:* ``string``, *default:* ``None``
 
+``--source``
+    Origin of the whois file.
+
+    *Type:* ``string``, *default:* ``whois``
+
 Custom config file options
 ^^^^^^^^^^^^^^^^^^^^^^^^^^
 
@@ -86,8 +91,8 @@ Exception file format
 The exception file is an ordinary text file containing single IPv(4|6)
 address|network|range on each line. Blank lines and lines beginning with ``#``
 are ignored. Whois exception files are very easy to be generated and they are meant
-for specifiing whois resolving exceptions. For example you may use it to describe
-hosts with addresses from the domain of one particular abuse group, but actualy
+for specifying whois resolving exceptions. For example you may use it to describe
+hosts with addresses from the domain of one particular abuse group, but actually
 belonging to different group. This might be the case of routers belonging to service
 provider but residing within the network address space of the customer. Another
 example may be nodes of some cloud computing service that have addresses from
@@ -106,59 +111,65 @@ tool, which is an internal custom copy of relevant RIPE whois data. It is JSON b
 format. Following example content describes multiple valid syntaxes for describing
 network records::
 
-    {
-        "__whois_about__" "Generated by Custom tool(tm) at 2018-01-25 01:00:01.765858.",
-        "__whois_type__": "custom",
-
+    [
         # Option 1: Pass IP4 start and end addresses
-        "78.128.128.0 - 78.128.255.255": {
+        {
+            "primary_key": "78.128.128.0 - 78.128.255.255",
             "ip4_start": "78.128.128.0",
             "ip4_end": "78.128.255.255",
-            "netname": "CZ-TEN-34-20070410",
-            "resolved_abuses": [
+            "netnames": ["CZ-TEN-34-20070410"],
+            "resolved_abuses": {
+              "low": [
                 "abuse@cesnet.cz"
-            ]
+              ]
+            }
         },
 
         # Option 2: Pass network CIDR or range and type
-        "78.128.212.64 - 78.128.212.127": {
+        {
+            "primary_key": "78.128.212.64 - 78.128.212.127",
             "network": "78.128.212.64/26",
             "type": "ipv4",
-            "netname": "CESNET-HSM4",
+            "netnames": ["CESNET-HSM4"],
             "descr": [
               "CESNET, z.s.p.o.",
               "Ostrava"
             ],
-            "resolved_abuses": [
-              "abuse@cesnet.cz"
-            ]
+            "resolved_abuses": {
+              "low": [
+                "abuse@cesnet.cz"
+              ]
+            }
         },
 
         # Option 3: Pass IP6 address and prefix
-        "2001:718::/29": {
+        {
+            "primary_key": "2001:718::/29",
             "ip6_addr": "2001:718::",
             "ip6_prefix": 29,
-            "netname": "CZ-TEN-34-20010521",
-            "description": "Extensive network description",
-            "resolved_abuses": [
+            "netnames": ["CZ-TEN-34-20010521"],
+            "descr": ["Extensive network description"],
+            "resolved_abuses": {
+              "low": [
                 "abuse@cesnet.cz"
-            ]
+              ]
+            }
         },
 
         # Option 4: Pass only IPv(4|6) network|range without type for autodetection (slower)
-        "2001:718::/29": {
+        {
+            "primary_key": "2001:718::/29",
             "network": "2001:718::/29",
-            "netname": "CZ-TEN-34-20010521",
-            "resolved_abuses": [
-              "abuse@cesnet.cz"
-            ]
+            "netnames": ["CZ-TEN-34-20010521"],
+            "resolved_abuses": {
+              "low": [
+                "abuse@cesnet.cz"
+              ]
+            }
         },
         ...
-    }
+    ]
 
-The ``__whois_type__`` meta attribute has a deeper meaning. It is used throughout
-the database records to mark their origin. It is possible to keep track which
-tool provided which whois network records.
 
 The ``netname``, ``descr`` and ``description`` attributes are optional and will
 be used/stored into database, if present.
@@ -166,16 +177,6 @@ be used/stored into database, if present.
 The ``resolved_abuses`` attribute is mandatory and must contain list of abuse groups
 (abuse contacts) for that particular network record.
 
-For the purposes of cooperation with the *Negistry* tool following header is also
-recognized and automatically sets up the ``__whois_type__`` header to value
-``negistry``::
-
-    {
-        "__negistry_about__": "Generated by Negistry at 2018-01-25 01:00:01.765858.",
-        ...
-    }
-
-
 """
 
 
@@ -185,7 +186,6 @@ __credits__ = "Pavel Kácha <pavel.kacha@cesnet.cz>, Andrea Kropáčová <andrea
 
 import re
 import json
-import datetime
 import collections
 
 #
@@ -199,10 +199,6 @@ from mentat.datatype.sqldb import GroupModel, NetworkModel, SettingsReportingMod
     networkmodel_from_typeddict
 
 
-WHOIS_KEY_TYPE           = '__whois_type__'
-WHOIS_KEY_ABOUT_GENERIC  = '__whois_about__'
-WHOIS_KEY_ABOUT_NEGISTRY = '__negistry_about__'
-
 WHOIS_TYPE_GENERIC  = 'whois'
 WHOIS_TYPE_NEGISTRY = 'negistry'
 
@@ -222,6 +218,7 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
 
     # List of configuration keys.
     CONFIG_WHOIS_FILE      = 'whois_file'
+    CONFIG_WHOIS_SOURCE    = 'source'
     CONFIG_EXCEPTION_FILES = 'exception_files'
 
 
@@ -267,6 +264,13 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
             help = 'path to reference whois file containing network data'
         )
 
+        arggroup_script.add_argument(
+            '--source',
+            type = str,
+            default = WHOIS_TYPE_GENERIC,
+            help = 'origin of the whois file'
+        )
+
         return argparser
 
     def _init_config(self, cfgs, **kwargs):
@@ -284,8 +288,9 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :rtype: dict
         """
         cfgs = (
-            (self.CONFIG_WHOIS_FILE,      None),
-            (self.CONFIG_EXCEPTION_FILES, None)
+            (self.CONFIG_WHOIS_FILE,        None),
+            (self.CONFIG_WHOIS_SOURCE,      WHOIS_TYPE_GENERIC),
+            (self.CONFIG_EXCEPTION_FILES,   None)
         ) + cfgs
         return super()._init_config(cfgs, **kwargs)
 
@@ -350,11 +355,11 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         """
         The actual worker method for processing group and network records.
 
-        :param bool status_only: Do not actualy perform any database operations, just report status.
+        :param bool status_only: Do not actually perform any database operations, just report status.
         :return: Structure containing information about changes.
         :rtype: dict
         """
-        result = {'create': {}, 'delete': {}}
+        result = {'create': {}, 'delete': {}, 'update': {}}
         abuse_group_dict = {}
 
         wi_file = self.c(self.CONFIG_WHOIS_FILE)
@@ -362,13 +367,19 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         wi_file_data = self._process_whois_data(wi_file_data_raw, wi_file_type)
         self.logger.info("Number of abuse groups in reference whois file: %d", len(wi_file_data.keys()))
 
-        abuse_groups = self.sqlservice.session.query(GroupModel).order_by(GroupModel.name).all()
+        abuse_groups = self.sqlservice.session.query(GroupModel).filter(GroupModel.enabled == True).order_by(GroupModel.name).all()
         self.sqlservice.session.commit()
 
         for abg in abuse_groups:
-            abuse_group_dict[abg.name] = abg
+            # The name of an abuse group is variable and may change anytime. In order to match abuse groups
+            # from the whois file with those from the database, the name of each group from database is computed
+            # in the same way as the name of a group from the whois file.
+            emails = list(set((abg.settings_rep.emails_low or []) + (abg.settings_rep.emails_medium or []) + (abg.settings_rep.emails_high or []) + (abg.settings_rep.emails_critical or [])))
+            name = ','.join(sorted(map(str.lower, emails if emails else [abg.name])))
+            abuse_group_dict[name] = abg
         self.logger.info("Number of abuse groups in database: %d", len(abuse_groups))
 
+        self._check_emails(abuse_group_dict, wi_file_data)
         self._groups_create_missing(abuse_group_dict, wi_file_data, wi_file_type, result, status_only)
         self._groups_remove_extra(abuse_group_dict, wi_file_data, wi_file_type, result, status_only)
         self._groups_update_existing(abuse_group_dict, wi_file_data, result, status_only)
@@ -384,28 +395,14 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :rtype: dict
         """
         try:
-            whois_file_data = self.json_load(whois_file)
+            with open(whois_file, 'r') as jsf:
+                json_data = jsf.read()
+            whois_file_data = json.loads(json_data)
         except:
             raise pyzenkit.zenscript.ZenScriptException("Invalid whois file '{}', expected JSON formated file".format(whois_file))
 
-        # Each valid whois file must contain either '__negistry_about__' or
-        # '__whois_about__' header. Attempt to find them
-        whois_file_about = None
-        whois_file_type = WHOIS_TYPE_GENERIC
-        for meta in (WHOIS_KEY_ABOUT_GENERIC, WHOIS_KEY_ABOUT_NEGISTRY):
-            if meta in whois_file_data:
-                whois_file_about = whois_file_data[meta]
-                del whois_file_data[meta]
-                if meta == WHOIS_KEY_ABOUT_NEGISTRY:
-                    whois_file_type = WHOIS_TYPE_NEGISTRY
-                elif WHOIS_KEY_TYPE in whois_file_data:
-                    whois_file_type = whois_file_data[WHOIS_KEY_TYPE]
-                    del whois_file_data[WHOIS_KEY_TYPE]
-                break
-        if not whois_file_about:
-            raise pyzenkit.zenscript.ZenScriptException("Invalid whois file '{}', missing meta information header".format(whois_file))
-
-        self.logger.info("Loaded reference whois file '%s :: %s' (%s)", whois_file, whois_file_type, whois_file_about)
+        whois_file_type = self.c(self.CONFIG_WHOIS_SOURCE)
+        self.logger.info("Loaded reference whois file '%s :: %s'", whois_file, whois_file_type)
         return (whois_file_type, whois_file_data)
 
     @staticmethod
@@ -420,17 +417,60 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :rtype: dict
         """
         processed_data = collections.defaultdict(dict)
-        for network_data in whois_file_data.values():
-            nwr    = mentat.datatype.internal.t_network_record(network_data, source = whois_file_type)
+        for network_data in whois_file_data:
+            nwr = mentat.datatype.internal.t_network_record(network_data, source = whois_file_type)
             nwrkey = nwr['network']
-            for abuse_group in network_data['resolved_abuses']:
-                processed_data[abuse_group][nwrkey] = nwr
+            # abuse_group is created as a concatenation of sorted emails in lowercase across
+            # all severities with ',' as the delimiter.
+            if not 'abuse_group' in nwr:
+                continue
+            abuse_group = nwr['abuse_group']
+            # It is possible to have multiple networks with the same nwrkey, because the
+            # networks may come from different feeds.
+            if not nwrkey in processed_data[abuse_group]:
+                processed_data[abuse_group][nwrkey] = []
+            processed_data[abuse_group][nwrkey].append(nwr)
         return processed_data
 
 
     #---------------------------------------------------------------------------
 
 
+    def _check_emails(self, abuse_group_dict, wi_file_data):
+        """
+        Check that each abuse group has the same emails in every severity across all networks.
+
+        The name of an abuse group is created as a concatenation of all emails across all severities.
+        The code is expecting that the distribution of emails of an abuse group is the same in every network.
+        This function checks the consistency and logs an error in case of the inconsistency.
+
+        :param dict abuse_group_dict: Abuse groups and network records loaded from database.
+        :param dict wi_file_data: Abuse groups and network records loaded from reference whois file.
+        """
+        for abuse_group in wi_file_data:
+            emails = {'low': [], 'medium': [], 'high': [], 'critical': []}
+            for nwrkey in wi_file_data[abuse_group]:
+                for network in wi_file_data[abuse_group][nwrkey]:
+                    if 'emails_fallback' in network:
+                        continue
+                    for severity in ['low', 'medium', 'high', 'critical']:
+                        emails[severity].append(sorted(map(str.lower, list(set(network.get('emails_{}'.format(severity), []))))))
+
+            if abuse_group in abuse_group_dict:
+                s = abuse_group_dict[abuse_group].settings_rep
+                if not (s.emails_low or s.emails_medium or s.emails_high or s.emails_critical):
+                    emails['low'].append([abuse_group])
+                else:
+                    emails['low'].append(sorted(s.emails_low or []))
+                    emails['medium'].append(sorted(s.emails_medium or []))
+                    emails['high'].append(sorted(s.emails_high or []))
+                    emails['critical'].append(sorted(s.emails_critical or []))
+
+            for severity in ['low', 'medium', 'high', 'critical']:
+                if not all(x == emails[severity][0] for x in emails[severity]):
+                    self.logger.error("Abuse group %s has inconsistent emails across networks", abuse_group)
+
+
     def _groups_create_missing(self, abuse_group_dict, wi_file_data, wi_file_type, result, status_only):
         """
         Create missing abuse groups and their appropriate whois records within
@@ -440,16 +480,20 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :param dict wi_file_data: Abuse groups and network records loaded from reference whois file.
         :param str wi_file_type: Value of ``__whois_type__`` meta attribute from reference whois file.
         :param dict result: Structure containing processing log, will be appended to script runlog.
-        :param bool status_only: Do not actualy perform any database operations, just report status.
+        :param bool status_only: Do not actually perform any database operations, just report status.
         """
+        # abuse_group_names is a list of actual names of abuse groups stored in the database,
+        # abuse_group_dict.keys() is a list of group names created from emails
+        abuse_group_names = [group.name for group in abuse_group_dict.values()]
         for group_name in sorted(wi_file_data.keys()):
-            if not group_name in abuse_group_dict:
+            # Try finding the group from the file primarily by emails and secondarily by name of the group.
+            if not group_name in abuse_group_dict and not group_name in abuse_group_names:
                 gkey = '{}::{}'.format(group_name, wi_file_type)
                 result['create'][gkey] = []
 
                 if status_only:
                     self.logger.warning("'%s' Found new abuse group.", gkey)
-                    for network in wi_file_data[group_name].values():
+                    for network in [network for networks in wi_file_data[group_name].values() for network in networks]:
                         nkey = '{}::{}'.format(network['network'], network['source'])
                         result['create'][gkey].append(nkey)
                         self.logger.warning("'%s' Found new network '%s'.", gkey, nkey)
@@ -462,7 +506,19 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
                 sqlgrp.settings_rep = SettingsReportingModel()
                 self.logger.warning("'%s' Creating new abuse group.", gkey)
 
-                for network in wi_file_data[group_name].values():
+                checked_group_name = False
+                for network in [network for networks in wi_file_data[group_name].values() for network in networks]:
+                    # If there are multiple emails in this abuse group or lowest severity is not low then save
+                    # emails in the reporting settings. By default, if the group in the database doesn't have
+                    # any emails set in the reporting settings then the name of the abuse group is used as
+                    # email address for every severity.
+                    if not checked_group_name:
+                        if ',' in group_name or any(severity in network for severity in ['emails_medium', 'emails_high', 'emails_critical']):
+                            sqlgrp.settings_rep.emails_low = network.get('emails_low', None)
+                            sqlgrp.settings_rep.emails_medium = network.get('emails_medium', None)
+                            sqlgrp.settings_rep.emails_high = network.get('emails_high', None)
+                            sqlgrp.settings_rep.emails_critical = network.get('emails_critical', None)
+                        checked_group_name = True
                     sqlnet = networkmodel_from_typeddict(
                         network,
                         {'description': 'Network created automatically by mentat-netmngr.py utility.'}
@@ -485,14 +541,14 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :param dict wi_file_data: Abuse groups and network records loaded from reference whois file.
         :param str wi_file_type: Value of ``__whois_type__`` meta attribute from reference whois file.
         :param dict result: Structure containing processing log, will be appended to script runlog.
-        :param bool status_only: Do not actualy perform any database operations, just report status.
+        :param bool status_only: Do not actually perform any database operations, just report status.
         """
         for group_name in sorted(abuse_group_dict.keys()):
             abg = abuse_group_dict[group_name]
 
             # For deletion consider only groups with the same origin (source) as
             # the loaded whois file.
-            if abg.source == wi_file_type and not group_name in wi_file_data:
+            if abg.source == wi_file_type and group_name not in wi_file_data and abg.name not in wi_file_data:
                 gkey = '{}::{}'.format(abg.name, abg.source)
                 result['delete'][gkey] = []
                 self.logger.warning("'%s' Group was not found in loaded whois file, consider deletion.", gkey)
@@ -500,7 +556,7 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
                 for net in abg.networks:
                     nkey = '{}::{}'.format(net.network, net.source)
                     result['delete'][gkey].append(nkey)
-                    self.logger.warning("'%s' Network was '%s' not found in loaded whois file, consider deletion.", gkey, nkey)
+                    self.logger.warning("'%s' Network '%s' was not found in loaded whois file, consider deletion.", gkey, nkey)
 
     def _groups_update_existing(self, abuse_group_dict, wi_file_data, result, status_only):
         """
@@ -510,13 +566,16 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :param dict abuse_group_dict: Abuse groups and network records loaded from database.
         :param dict wi_file_data: Abuse groups and network records loaded from reference whois file.
         :param dict result: Structure containing processing log, will be appended to script runlog.
-        :param bool status_only: Do not actualy perform any database operations, just report status.
+        :param bool status_only: Do not actually perform any database operations, just report status.
         """
         for group_name in sorted(abuse_group_dict.keys()):
-            if group_name in wi_file_data:
+            name = None
+            if group_name in wi_file_data: name = group_name
+            if abuse_group_dict[group_name].name in wi_file_data: name = abuse_group_dict[group_name].name
+            if name:
                 self._group_update_networks(
                     abuse_group_dict[group_name],
-                    wi_file_data[group_name].values(),
+                    [network for networks in wi_file_data[name].values() for network in networks],
                     result,
                     status_only)
                 self.sqlservice.session.commit()
@@ -528,12 +587,13 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :param mentat.datatype.sqldb.GroupModel group: Abuse group to be processed.
         :param list networks: List of network records loaded from reference whois file.
         :param dict result: Structure containing processing log, will be appended to script runlog.
-        :param bool status_only: Do not actualy perform any database operations, just report status.
+        :param bool status_only: Do not actually perform any database operations, just report status.
         """
         gkey = '{}::{}'.format(group.name, group.source)
         for net in networks:
-            if not self._is_network_in(net, group.networks):
-                nkey = '{}::{}'.format(net['network'], net['source'])
+            nkey = '{}::{}'.format(net['network'], net['source'])
+            index = self._get_index_of_network(net, group.networks)
+            if index == -1:
                 result['create'].setdefault(gkey, []).append(nkey)
                 if status_only:
                     self.logger.warning("'%s' Found new network '%s'.", gkey, nkey)
@@ -546,6 +606,26 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
                 self.logger.warning("'%s' Creating new network '%s'.", gkey, nkey)
                 group.networks.append(sqlnet)
 
+            elif self._network_has_changed(net, group.networks[index]):
+                result['update'].setdefault(gkey, []).append(nkey)
+                if status_only:
+                    self.logger.warning("'%s' Network '%s' has changed.", gkey, nkey)
+                    if group.networks[index].rank != net.get('rank', None):
+                        self.logger.debug("Rank: '%s' -> '%s'", group.networks[index].rank, net.get('rank', None))
+                    if group.networks[index].source != net['source']:
+                        self.logger.debug("Source: '%s' -> '%s'", group.networks[index].source, net['source'])
+                    if group.networks[index].netname != net['netname']:
+                        self.logger.debug("Netname: '%s' -> '%s'", group.networks[index].netname, net['netname'])
+                    if group.networks[index].is_base != net['is_base']:
+                        self.logger.debug("is_base: '%s' -> '%s'", str(group.networks[index].is_base), str(net['is_base']))
+                    continue
+
+                self.logger.warning("'%s' Updating existing network '%s'.", gkey, nkey)
+                group.networks[index].rank = net.get('rank', None)
+                group.networks[index].source = net['source']
+                group.networks[index].netname = net['netname']
+                group.networks[index].is_base = net['is_base']
+
         for net in group.networks:
             if not self._is_network_in(net, networks):
                 nkey = '{}::{}'.format(net.network, net.source)
@@ -560,6 +640,25 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
 
     #---------------------------------------------------------------------------
 
+    @staticmethod
+    def _get_index_of_network(network, netlist):
+        """
+        Get the index of a network in a given network list or return -1 if the list doesn't contain the network.
+
+        :param network: Instance of :py:class:`mentat.datatype.sqldb.NetworkModel` or :py:class:`mentat.datatype.internal.NetworkRecord`
+        :param netlist: List of instances of :py:class:`mentat.datatype.sqldb.NetworkModel` or :py:class:`mentat.datatype.internal.NetworkRecord`
+        :return: index of network
+        :rtype: int
+        """
+        if isinstance(network, NetworkModel):
+            for index, net in enumerate(netlist):
+                if network.network == net['network'] and (('netname' in net and network.netname == net['netname']) or network.source == net['source']):
+                    return index
+        else:
+            for index, net in enumerate(netlist):
+                if net.network == network['network'] and (('netname' in network and net.netname == network['netname']) or net.source == network['source']):
+                    return index
+        return -1
 
     @staticmethod
     def _is_network_in(network, netlist):
@@ -571,15 +670,29 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :return: True or False
         :rtype: bool
         """
-        if isinstance(network, NetworkModel):
-            for net in netlist:
-                if network.network == net['network']:
-                    return True
+        return MentatNetmngrScript._get_index_of_network(network, netlist) != -1
+
+    @staticmethod
+    def _network_has_changed(original_network, new_network):
+        """
+        Check if the given network has changed.
+        Currently, two networks with the same key differ if their ranks or is_base flags differ.
+
+        :param orignal_network: Instance of :py:class:`mentat.datatype.sqldb.NetworkModel` or :py:class:`mentat.datatype.internal.NetworkRecord`
+        :param new_network: Instance of :py:class:`mentat.datatype.sqldb.NetworkModel` or :py:class:`mentat.datatype.internal.NetworkRecord`
+        :return: True or False
+        :rtype: bool
+        """
+        if isinstance(original_network, NetworkModel):
+            if isinstance(new_network, NetworkModel):
+                return original_network.rank != new_network.rank or original_network.is_base != new_network.is_base
+            else:
+                return original_network.rank != new_network.get('rank', None) or original_network.is_base != new_network.get('is_base')
         else:
-            for net in netlist:
-                if net.network == network['network']:
-                    return True
-        return False
+            if isinstance(new_network, NetworkModel):
+                return original_network.get('rank', None) != new_network.rank or original_network.get('is_base') != new_network.is_base
+            else:
+                return original_network.get('rank', None) != new_network.get('rank', None) or original_network.get('is_base') != new_network.get('is_base')
 
     def _load_exceptions_file(self, path, abuse):
         """
@@ -601,8 +714,8 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
                 match = PTRN_EXCEPTION_MATCH.match(line)
                 if match:
                     exc = {
-                        'network':         match.group(1),
-                        'resolved_abuses': [abuse]
+                        'network':     match.group(1),
+                        'abuse_group': abuse
                     }
                     exc = mentat.datatype.internal.t_network_record(exc, source = 'exception')
                     self.logger.info("Found whois exception '%s' for abuse group '%s'", exc['network'], abuse)
@@ -616,16 +729,17 @@ class MentatNetmngrScript(mentat.script.fetcher.FetcherScript):
         :param str whois_file: path to target whois file.
         :param dict exceptions: Structure containing whois exceptions.
         """
-        exception_dict = {
-            WHOIS_KEY_TYPE: 'exceptions',
-            WHOIS_KEY_ABOUT_GENERIC: 'Generated at {}'.format(str(datetime.datetime.now()))
-        }
+        exception_dict = []
         for exc in exceptions:
-            exception_dict[exc['network']] = {
-                'network':         exc['network'],
-                'type':            exc['type'],
-                'resolved_abuses': list(exc['resolved_abuses'])
-            }
+            exception_dict.append(
+                {
+                    'primary_key':     exc['network'],
+                    'type':            exc['type'],
+                    'resolved_abuses': {
+                        'low': list(exc['resolved_abuses'])
+                    }
+                }
+            )
         with open(whois_file, 'w') as excfh:
             json.dump(exception_dict, excfh, indent = 4, sort_keys = True)
         self.logger.info("Saved '%d' whois exceptions into target file '%s'", len(exceptions), whois_file)
