@@ -79,7 +79,7 @@ class TestMentatReportsUtils(unittest.TestCase):
                     'SW': ['Kippo']
                 }
             ],
-            '_CESNET' : {
+            '_Mentat' : {
                 'ResolvedAbuses' : [
                     'abuse@cesnet.cz'
                 ],
@@ -111,7 +111,7 @@ class TestMentatReportsUtils(unittest.TestCase):
                     'SW': ['Dionaea']
                 }
             ],
-            '_CESNET' : {
+            '_Mentat' : {
                 'ResolvedAbuses' : [
                     'abuse@cesnet.cz'
                 ],
@@ -144,7 +144,7 @@ class TestMentatReportsUtils(unittest.TestCase):
         self.eventstorage.database_drop()
         self.eventstorage.database_create()
         for event in self.ideas_obj:
-            event['_CESNET']['StorageTime'] = datetime.datetime.utcnow()
+            event['_Mentat']['StorageTime'] = datetime.datetime.utcnow()
             self.eventstorage.insert_event(event)
 
         group = GroupModel(name = 'abuse@cesnet.cz',  source = 'manual', description = 'CESNET, z.s.p.o.')
@@ -265,15 +265,11 @@ class TestMentatReportsUtils(unittest.TestCase):
         self.assertEqual(str(reporting_settings.filters), "[<Filter(name='FLT1')>, <Filter(name='FLT2')>]")
         self.assertEqual(str(reporting_settings.networks), "[<Network(netname='UNET1',network='10.0.0.0/8')>]")
         self.assertEqual(reporting_settings.mode, 'summary')
-        self.assertEqual(reporting_settings.attachments, 'json')
-        self.assertEqual(reporting_settings.emails, ['abuse@cesnet.cz'])
-        self.assertEqual(reporting_settings.mute, False)
+        self.assertEqual(reporting_settings.emails, (['abuse@cesnet.cz'], [], [], []))
         self.assertEqual(reporting_settings.redirect, False)
-        self.assertEqual(reporting_settings.compress, False)
         self.assertEqual(reporting_settings.template, 'default')
         self.assertEqual(reporting_settings.locale, 'en')
         self.assertEqual(reporting_settings.timezone, 'UTC')
-        self.assertEqual(reporting_settings.max_size, 10485760)
         self.assertEqual(reporting_settings.timing, 'default')
         self.assertEqual(reporting_settings.timing_cfg, {
             'critical': {
@@ -302,18 +298,14 @@ class TestMentatReportsUtils(unittest.TestCase):
         reporting_settings = mentat.reports.utils.ReportingSettings(
             abuse_group,
             force_mode          = 'both',
-            force_attachments   = 'all',
             force_template      = 'another',
             force_locale        = 'cs',
-            force_timezone      = 'America/Los_Angeles',
-            force_maxattachsize = 1024
+            force_timezone      = 'America/Los_Angeles'
         )
         self.assertEqual(reporting_settings.mode, 'both')
-        self.assertEqual(reporting_settings.attachments, 'all')
         self.assertEqual(reporting_settings.template, 'another')
         self.assertEqual(reporting_settings.locale, 'cs')
         self.assertEqual(reporting_settings.timezone, 'America/Los_Angeles')
-        self.assertEqual(reporting_settings.max_size, 1024)
         pprint.pprint(reporting_settings)
 
         filter_parser   = PynspectFilterParser()
