@@ -68,10 +68,10 @@ ENUM_TABLES = (
     "node_type",
     "source_type",
     "target_type",
-    "cesnet_resolvedabuses",
-    "cesnet_eventclass",
-    "cesnet_eventseverity",
-    "cesnet_inspectionerrors"
+    "resolvedabuses",
+    "eventclass",
+    "eventseverity",
+    "inspectionerrors"
 )
 
 EVENTS_COLUMNS = (
@@ -92,11 +92,11 @@ EVENTS_COLUMNS = (
     "protocol",
     "node_name",
     "node_type",
-    "cesnet_resolvedabuses",
-    "cesnet_storagetime",
-    "cesnet_eventclass",
-    "cesnet_eventseverity",
-    "cesnet_inspectionerrors",
+    "resolvedabuses",
+    "storagetime",
+    "eventclass",
+    "eventseverity",
+    "inspectionerrors",
 )
 
 EVENTS_COLUMNS_ARRAY = (
@@ -110,8 +110,8 @@ EVENTS_COLUMNS_ARRAY = (
     "protocol",
     "node_name",
     "node_type",
-    "cesnet_resolvedabuses",
-    "cesnet_inspectionerrors",
+    "resolvedabuses",
+    "inspectionerrors",
 )
 
 EVENTS_COLUMNS_TOPLISTED = (
@@ -119,7 +119,7 @@ EVENTS_COLUMNS_TOPLISTED = (
     "target_ip",
     "source_port",
     "target_port",
-    "cesnet_resolvedabuses",
+    "resolvedabuses",
 )
 
 RE_QNAME      = ' AS "_mentatq\\(([^)]+)\\)_"'
@@ -299,10 +299,10 @@ def _bq_where(parameters):
             chunks.append(psycopg2.sql.SQL('{} <= %s').format(psycopg2.sql.Identifier('detecttime')))
             params.append(parameters['dt_to'])
         if parameters.get('st_from', None):
-            chunks.append(psycopg2.sql.SQL('{} >= %s').format(psycopg2.sql.Identifier('cesnet_storagetime')))
+            chunks.append(psycopg2.sql.SQL('{} >= %s').format(psycopg2.sql.Identifier('storagetime')))
             params.append(parameters['st_from'])
         if parameters.get('st_to', None):
-            chunks.append(psycopg2.sql.SQL('{} <= %s').format(psycopg2.sql.Identifier('cesnet_storagetime')))
+            chunks.append(psycopg2.sql.SQL('{} <= %s').format(psycopg2.sql.Identifier('storagetime')))
             params.append(parameters['st_to'])
 
         if parameters.get('host_addrs', None):
@@ -338,12 +338,12 @@ def _bq_where(parameters):
         for item in (
                 ('protocols',       'protocol',                _bq_param_multi_to_array),
                 ('categories',      'category',                _bq_param_multi_to_array),
-                ('classes',         'cesnet_eventclass',       _bq_param_multi_to_scalar),
-                ('severities',      'cesnet_eventseverity',    _bq_param_multi_to_scalar),
+                ('classes',         'eventclass',              _bq_param_multi_to_scalar),
+                ('severities',      'eventseverity',           _bq_param_multi_to_scalar),
                 ('detectors',       'node_name',               _bq_param_multi_to_array),
                 ('detector_types',  'node_type',               _bq_param_multi_to_array),
-                ('groups',          'cesnet_resolvedabuses',   _bq_param_multi_to_array),
-                ('inspection_errs', 'cesnet_inspectionerrors', _bq_param_multi_to_array),
+                ('groups',          'resolvedabuses',          _bq_param_multi_to_array),
+                ('inspection_errs', 'inspectionerrors',        _bq_param_multi_to_array),
             ):
             if parameters.get(item[0], None):
                 item[2](
@@ -420,13 +420,9 @@ def build_query(parameters = None, qtype = QTYPE_SELECT, qname = None):
     if qtype in (QTYPE_SELECT, QTYPE_SELECT_GHOST) and parameters:
         if parameters.get('sortby', None):
             field, direction = parameters['sortby'].split('.')
-            if field == 'detecttime':
-                field = 'detecttime'
-            elif field == 'storagetime':
-                field = 'cesnet_storagetime'
-            else:
+            if field != 'detecttime' and field != 'storagetime':
                 if parameters.get('st_from', None) or parameters.get('st_to', None):
-                    field = 'cesnet_storagetime'
+                    field = 'storagetime'
                 else:
                     field = 'detecttime'
 
@@ -594,7 +590,7 @@ class EventStorageCursor:
         record = idea_pgsql.get_record()
 
         self.cursor.execute(
-            "INSERT INTO events (id, detecttime, category, description, source_ip, target_ip, source_ip_aggr_ip4, source_ip_aggr_ip6, target_ip_aggr_ip4, target_ip_aggr_ip6, source_port, target_port, source_type, target_type, protocol, node_name, node_type, cesnet_resolvedabuses, cesnet_storagetime, cesnet_eventclass, cesnet_eventseverity, cesnet_inspectionerrors) VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)",
+            "INSERT INTO events (id, detecttime, category, description, source_ip, target_ip, source_ip_aggr_ip4, source_ip_aggr_ip6, target_ip_aggr_ip4, target_ip_aggr_ip6, source_port, target_port, source_type, target_type, protocol, node_name, node_type, resolvedabuses, storagetime, eventclass, eventseverity, inspectionerrors) VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)",
             record[0:-1]
         )
         self.cursor.execute(
@@ -767,7 +763,7 @@ class EventStorageCursor:
         """
         params = ('{:d}s'.format(interval),)
         query = psycopg2.sql.SQL("SELECT max({}) > NOW() AT TIME ZONE 'GMT' - INTERVAL %s AS watchdog FROM events").\
-            format(psycopg2.sql.Identifier('cesnet_storagetime'))
+            format(psycopg2.sql.Identifier('storagetime'))
         self.lastquery = self.cursor.mogrify(query, params)
 
         self.cursor.execute(query, params)
@@ -1121,7 +1117,7 @@ class EventStorageService:
         """
         # Base list of CREATE TABLE SQLs.
         create_table_sqls = [
-            "CREATE TABLE IF NOT EXISTS events(id text PRIMARY KEY, detecttime timestamp NOT NULL, category text[] NOT NULL, description text, source_ip iprange[], target_ip iprange[], source_ip_aggr_ip4 ip4r, source_ip_aggr_ip6 ip6r, target_ip_aggr_ip4 ip4r, target_ip_aggr_ip6 ip6r, source_port integer[], target_port integer[], source_type text[], target_type text[], protocol text[], node_name text[] NOT NULL, node_type text[], cesnet_storagetime timestamp NOT NULL, cesnet_resolvedabuses text[], cesnet_eventclass text, cesnet_eventseverity text, cesnet_inspectionerrors text[])",
+            "CREATE TABLE IF NOT EXISTS events(id text PRIMARY KEY, detecttime timestamp NOT NULL, category text[] NOT NULL, description text, source_ip iprange[], target_ip iprange[], source_ip_aggr_ip4 ip4r, source_ip_aggr_ip6 ip6r, target_ip_aggr_ip4 ip4r, target_ip_aggr_ip6 ip6r, source_port integer[], target_port integer[], source_type text[], target_type text[], protocol text[], node_name text[] NOT NULL, node_type text[], storagetime timestamp NOT NULL, resolvedabuses text[], eventclass text, eventseverity text, inspectionerrors text[])",
             "CREATE TABLE IF NOT EXISTS events_json(id text PRIMARY KEY REFERENCES events(id) ON DELETE CASCADE, event bytea NOT NULL)",
             "CREATE TABLE IF NOT EXISTS thresholds(id text PRIMARY KEY, thresholdtime timestamp NOT NULL, relapsetime timestamp NOT NULL, ttltime timestamp NOT NULL)",
             "CREATE TABLE IF NOT EXISTS events_thresholded(eventid text NOT NULL, keyid text NOT NULL, groupname text NOT NULL, eventseverity text NOT NULL, createtime timestamp NOT NULL, PRIMARY KEY(eventid, keyid))"
@@ -1151,9 +1147,10 @@ class EventStorageService:
         # Base list of CREATE INDEX SQLs.
         create_index_sqls = [
             "CREATE INDEX IF NOT EXISTS events_detecttime_idx ON events USING BTREE (detecttime)",
-            "CREATE INDEX IF NOT EXISTS events_cesnet_storagetime_idx ON events USING BTREE (cesnet_storagetime)",
-            "CREATE INDEX IF NOT EXISTS events_cesnet_eventseverity_idx ON events USING BTREE (cesnet_eventseverity) WHERE cesnet_eventseverity IS NOT NULL",
-            "CREATE INDEX IF NOT EXISTS events_combined_idx ON events USING GIN (category, node_name, protocol, source_port, target_port, source_type, target_type, node_type, cesnet_resolvedabuses, cesnet_inspectionerrors)",
+            "CREATE INDEX IF NOT EXISTS events_storagetime_idx ON events USING BTREE (storagetime)",
+            "CREATE INDEX IF NOT EXISTS events_eventseverity_idx ON events USING BTREE (eventseverity) WHERE eventseverity IS NOT NULL",
+            "CREATE INDEX IF NOT EXISTS events_combined_idx ON events USING GIN (category, node_name, protocol, source_port, target_port, source_type, target_type, node_type, resolvedabuses, inspectionerrors)",
+            "CREATE INDEX IF NOT EXISTS events_ip_aggr_idx ON events USING GIST (source_ip_aggr_ip4, target_ip_aggr_ip4, source_ip_aggr_ip6, target_ip_aggr_ip6)",
             "CREATE INDEX IF NOT EXISTS thresholds_thresholdtime_idx ON thresholds USING BTREE (thresholdtime)",
             "CREATE INDEX IF NOT EXISTS thresholds_relapsetime_idx ON thresholds USING BTREE (relapsetime)",
             "CREATE INDEX IF NOT EXISTS thresholds_ttltime_idx ON thresholds USING BTREE (ttltime)",
@@ -1217,10 +1214,11 @@ class EventStorageService:
         # Base list of DROP INDEX SQLs.
         drop_index_sqls = [
             "DROP INDEX IF EXISTS events_detecttime_idx",
-            "DROP INDEX IF EXISTS events_cesnet_storagetime_idx",
-            "DROP INDEX IF EXISTS events_cesnet_resolvedabuses_idx",
-            "DROP INDEX IF EXISTS events_cesnet_eventseverity_idx",
+            "DROP INDEX IF EXISTS events_storagetime_idx",
+            "DROP INDEX IF EXISTS events_resolvedabuses_idx",
+            "DROP INDEX IF EXISTS events_eventseverity_idx",
             "DROP INDEX IF EXISTS events_combined_idx",
+            "DROP INDEX IF EXISTS events_ip_aggr_idx",
             "DROP INDEX IF EXISTS thresholds_thresholdtime_idx",
             "DROP INDEX IF EXISTS thresholds_relapsetime_idx",
             "DROP INDEX IF EXISTS thresholds_ttltime_idx",
@@ -1445,11 +1443,11 @@ class EventStorageService:
         enum_table = "enum_{}".format(column)
         # Build and execute query for updating enumeration table.
         enum_query = psycopg2.sql.SQL("INSERT INTO {} (SELECT * FROM (").format(psycopg2.sql.Identifier(enum_table))
-        if column not in ('cesnet_eventclass', 'cesnet_eventseverity'):
+        if column not in ('eventclass', 'eventseverity'):
             enum_query += psycopg2.sql.SQL("SELECT unnest({})").format(psycopg2.sql.Identifier(column))
         else:
             enum_query += psycopg2.sql.SQL("SELECT {}").format(psycopg2.sql.Identifier(column))
-        enum_query += psycopg2.sql.SQL(' AS data, max(cesnet_storagetime) AS last_seen FROM events WHERE cesnet_storagetime >= COALESCE((SELECT max(last_seen) FROM {}), (SELECT min(cesnet_storagetime) FROM events)) GROUP BY data) AS enum WHERE data IS NOT NULL) ON CONFLICT (data) DO UPDATE SET last_seen = excluded.last_seen').format(psycopg2.sql.Identifier(enum_table))
+        enum_query += psycopg2.sql.SQL(' AS data, max(storagetime) AS last_seen FROM events WHERE storagetime >= COALESCE((SELECT max(last_seen) FROM {}), (SELECT min(storagetime) FROM events)) GROUP BY data) AS enum WHERE data IS NOT NULL) ON CONFLICT (data) DO UPDATE SET last_seen = excluded.last_seen').format(psycopg2.sql.Identifier(enum_table))
         self.cursor.execute(enum_query)
         self.commit()
 
@@ -1674,7 +1672,7 @@ class EventStorageService:
         #---
 
         table_wanted_list = [
-            ('events', 'cesnet_storagetime'),
+            ('events', 'storagetime'),
             ('events_json', None),
             ('events_thresholded', 'createtime'),
             ('thresholds', 'ttltime')
