@@ -111,7 +111,7 @@ class TestMentatStorage(unittest.TestCase):
                 'AggrWin': '00:05:00'
             }
         ],
-        '_CESNET' : {
+        '_Mentat' : {
             'StorageTime' : '2017-04-05T10:21:39Z',
             'EventTemplate' : 'sserv-012',
             'ResolvedAbuses' : [
@@ -162,7 +162,7 @@ class TestMentatStorage(unittest.TestCase):
                 "Proto": ["tcp"]
             }
         ],
-        "_CESNET": {
+        "_Mentat": {
             'StorageTime' : '2017-04-05T10:21:39Z',
             "EventClass": "attempt-login-telnet",
             "EventSeverity": "medium",
@@ -380,7 +380,7 @@ class TestMentatStorage(unittest.TestCase):
                         'st_to': datetime.datetime(2012, 11, 3, 10, 0, 7)
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_storagetime" >= \'2012-11-03T10:00:07\'::timestamp AND "cesnet_storagetime" <= \'2012-11-03T10:00:07\'::timestamp'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "storagetime" >= \'2012-11-03T10:00:07\'::timestamp AND "storagetime" <= \'2012-11-03T10:00:07\'::timestamp'
             ),
             (
                 {
@@ -390,7 +390,7 @@ class TestMentatStorage(unittest.TestCase):
                     },
                     'qtype': 'delete'
                 },
-                b'DELETE FROM events WHERE "cesnet_storagetime" >= \'2012-11-03T10:00:07\'::timestamp AND "cesnet_storagetime" <= \'2012-11-03T10:00:07\'::timestamp'
+                b'DELETE FROM events WHERE "storagetime" >= \'2012-11-03T10:00:07\'::timestamp AND "storagetime" <= \'2012-11-03T10:00:07\'::timestamp'
             ),
             (
                 {
@@ -400,7 +400,7 @@ class TestMentatStorage(unittest.TestCase):
                     },
                     'qtype': 'count'
                 },
-                b'SELECT count(id) FROM events WHERE "cesnet_storagetime" >= \'2012-11-03T10:00:07\'::timestamp AND "cesnet_storagetime" <= \'2012-11-03T10:00:07\'::timestamp'
+                b'SELECT count(id) FROM events WHERE "storagetime" >= \'2012-11-03T10:00:07\'::timestamp AND "storagetime" <= \'2012-11-03T10:00:07\'::timestamp'
             ),
             (
                 {
@@ -580,7 +580,7 @@ class TestMentatStorage(unittest.TestCase):
                         'classes': ['test', 'vulnerable-config-ssdp']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_eventclass" = ANY(ARRAY[\'test\',\'vulnerable-config-ssdp\'])'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "eventclass" = ANY(ARRAY[\'test\',\'vulnerable-config-ssdp\'])'
             ),
             (
                 {
@@ -589,7 +589,7 @@ class TestMentatStorage(unittest.TestCase):
                         'not_classes': True
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE NOT ("cesnet_eventclass" = ANY(ARRAY[\'test\',\'vulnerable-config-ssdp\']))'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE NOT ("eventclass" = ANY(ARRAY[\'test\',\'vulnerable-config-ssdp\']))'
             ),
             (
                 {
@@ -597,7 +597,7 @@ class TestMentatStorage(unittest.TestCase):
                         'classes': ['__EMPTY__']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("cesnet_eventclass",\'\') = \'\''
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("eventclass",\'\') = \'\''
             ),
             (
                 {
@@ -605,7 +605,7 @@ class TestMentatStorage(unittest.TestCase):
                         'classes': ['__ANY__']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("cesnet_eventclass",\'\') != \'\''
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("eventclass",\'\') != \'\''
             ),
             (
                 {
@@ -613,7 +613,7 @@ class TestMentatStorage(unittest.TestCase):
                         'severities': ['test', 'low']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_eventseverity" = ANY(ARRAY[\'test\',\'low\'])'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "eventseverity" = ANY(ARRAY[\'test\',\'low\'])'
             ),
             (
                 {
@@ -622,7 +622,7 @@ class TestMentatStorage(unittest.TestCase):
                         'not_severities': True
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE NOT ("cesnet_eventseverity" = ANY(ARRAY[\'test\',\'low\']))'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE NOT ("eventseverity" = ANY(ARRAY[\'test\',\'low\']))'
             ),
             (
                 {
@@ -630,7 +630,7 @@ class TestMentatStorage(unittest.TestCase):
                         'severities': ['__EMPTY__']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("cesnet_eventseverity",\'\') = \'\''
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("eventseverity",\'\') = \'\''
             ),
             (
                 {
@@ -638,7 +638,7 @@ class TestMentatStorage(unittest.TestCase):
                         'severities': ['__ANY__']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("cesnet_eventseverity",\'\') != \'\''
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE COALESCE("eventseverity",\'\') != \'\''
             ),
             (
                 {
@@ -712,7 +712,7 @@ class TestMentatStorage(unittest.TestCase):
                         'groups': ['abuse@cesnet.cz', 'abuse@nic.cz']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_resolvedabuses" && ARRAY[\'abuse@cesnet.cz\',\'abuse@nic.cz\']'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "resolvedabuses" && ARRAY[\'abuse@cesnet.cz\',\'abuse@nic.cz\']'
             ),
             (
                 {
@@ -721,7 +721,7 @@ class TestMentatStorage(unittest.TestCase):
                         'not_groups': True
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE NOT ("cesnet_resolvedabuses" && ARRAY[\'abuse@cesnet.cz\',\'abuse@nic.cz\'])'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE NOT ("resolvedabuses" && ARRAY[\'abuse@cesnet.cz\',\'abuse@nic.cz\'])'
             ),
             (
                 {
@@ -729,7 +729,7 @@ class TestMentatStorage(unittest.TestCase):
                         'groups': ['__EMPTY__']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_resolvedabuses" = \'{}\''
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "resolvedabuses" = \'{}\''
             ),
             (
                 {
@@ -737,7 +737,7 @@ class TestMentatStorage(unittest.TestCase):
                         'groups': ['__ANY__']
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_resolvedabuses" != \'{}\''
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "resolvedabuses" != \'{}\''
             ),
             (
                 {
@@ -772,7 +772,7 @@ class TestMentatStorage(unittest.TestCase):
                         'page': 11
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "cesnet_resolvedabuses" && ARRAY[\'abuse@cesnet.cz\',\'abuse@nic.cz\'] LIMIT 50 OFFSET 500'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) WHERE "resolvedabuses" && ARRAY[\'abuse@cesnet.cz\',\'abuse@nic.cz\'] LIMIT 50 OFFSET 500'
             ),
             (
                 {
@@ -796,7 +796,7 @@ class TestMentatStorage(unittest.TestCase):
                         'sortby': 'storagetime.desc'
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) ORDER BY "cesnet_storagetime" DESC'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) ORDER BY "storagetime" DESC'
             ),
             (
                 {
@@ -804,7 +804,7 @@ class TestMentatStorage(unittest.TestCase):
                         'sortby': 'storagetime.asc'
                     }
                 },
-                b'SELECT * FROM events INNER JOIN events_json USING(id) ORDER BY "cesnet_storagetime" ASC'
+                b'SELECT * FROM events INNER JOIN events_json USING(id) ORDER BY "storagetime" ASC'
             ),
         ]
 
@@ -867,11 +867,11 @@ class TestMentatStorage(unittest.TestCase):
                     'parameters': {
                         'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
                         'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
-                        'aggr_set': 'cesnet_eventclass',
+                        'aggr_set': 'eventclass',
                     },
                     'qtype': 'aggregate'
                 },
-                b'SELECT "cesnet_eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
+                b'SELECT "eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
             ),
             (
                 {
@@ -889,12 +889,12 @@ class TestMentatStorage(unittest.TestCase):
                     'parameters': {
                         'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
                         'dt_to': datetime.datetime(2012, 11, 3, 10, 0, 7),
-                        'aggr_set': 'cesnet_eventclass',
+                        'aggr_set': 'eventclass',
                         'limit': 10
                     },
                     'qtype': 'aggregate'
                 },
-                b'SELECT "cesnet_eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
+                b'SELECT "eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-11-03T10:00:07\'::timestamp GROUP BY set'
             ),
             (
                 {
@@ -925,11 +925,11 @@ class TestMentatStorage(unittest.TestCase):
                         'dt_from': datetime.datetime(2012, 11, 3, 10, 0, 7),
                         'dt_to': datetime.datetime(2012, 12, 3, 10, 0, 7),
                         'step': datetime.timedelta(days = 1),
-                        'aggr_set': 'cesnet_eventclass',
+                        'aggr_set': 'eventclass',
                     },
                     'qtype': 'timeline'
                 },
-                b'SELECT \'2012-11-03T10:00:07\'::timestamp + \'1 days 0.000000 seconds\'::interval * (width_bucket(detecttime,(SELECT array_agg(buckets) FROM generate_series(\'2012-11-03T10:00:07\'::timestamp,\'2012-12-03T10:00:07\'::timestamp,\'1 days 0.000000 seconds\'::interval) AS buckets)) - 1) AS bucket,"cesnet_eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-12-03T10:00:07\'::timestamp GROUP BY bucket, set ORDER BY bucket ASC'
+                b'SELECT \'2012-11-03T10:00:07\'::timestamp + \'1 days 0.000000 seconds\'::interval * (width_bucket(detecttime,(SELECT array_agg(buckets) FROM generate_series(\'2012-11-03T10:00:07\'::timestamp,\'2012-12-03T10:00:07\'::timestamp,\'1 days 0.000000 seconds\'::interval) AS buckets)) - 1) AS bucket,"eventclass" AS set,COUNT(*) FROM events WHERE "detecttime" >= \'2012-11-03T10:00:07\'::timestamp AND "detecttime" <= \'2012-12-03T10:00:07\'::timestamp GROUP BY bucket, set ORDER BY bucket ASC'
             ),
             (
                 {
@@ -1513,7 +1513,7 @@ class TestMentatStorage(unittest.TestCase):
         # ---
 
         idea_into = mentat.idea.internal.Idea(self.IDEA_RAW_1)
-        idea_into['_CESNET']['StorageTime'] = datetime.datetime.utcnow()
+        idea_into['_Mentat']['StorageTime'] = datetime.datetime.utcnow()
         storage.insert_event(idea_into)
         self.assertEqual(storage.count_events(), 1)
         time.sleep(1)
@@ -1644,12 +1644,12 @@ class TestMentatStorage(unittest.TestCase):
         )
 
         self.assertEqual(
-            storage.distinct_values('cesnet_eventclass'),
+            storage.distinct_values('eventclass'),
             ['vulnerable-config-ssdp']
         )
 
         self.assertEqual(
-            storage.distinct_values('cesnet_eventseverity'),
+            storage.distinct_values('eventseverity'),
             ['low']
         )
 
