@@ -90,17 +90,17 @@ LIST_STAT_GROUPS = (
 """List of statistical groups. The statistics will be calculated separatelly for these."""
 
 LIST_AGGREGATIONS = (
-    [ST_SKEY_IPS,        'Source.IP4',                    KEY_UNKNOWN],
-    #[ST_SKEY_IP4S,      'Source.IP4',                    KEY_UNKNOWN],
-    #[ST_SKEY_IP6S,      'Source.IP6',                    KEY_UNKNOWN],
-    [ST_SKEY_ANALYZERS,  'Node[#].SW',                    KEY_UNKNOWN],
-    [ST_SKEY_CATEGORIES, 'Category',                      KEY_UNKNOWN],
-    [ST_SKEY_DETECTORS,  'Node[#].Name',                  KEY_UNKNOWN],
-    [ST_SKEY_ABUSES,     '_CESNET.ResolvedAbuses',        KEY_UNKNOWN],
-    [ST_SKEY_ASNS,       '_CESNET.SourceResolvedASN',     KEY_UNKNOWN],
-    [ST_SKEY_COUNTRIES,  '_CESNET.SourceResolvedCountry', KEY_UNKNOWN],
-    [ST_SKEY_CLASSES,    '_CESNET.EventClass',            KEY_UNKNOWN],
-    [ST_SKEY_SEVERITIES, '_CESNET.EventSeverity',         KEY_UNKNOWN]
+    [ST_SKEY_IPS,        ('Source.IP4', 'Source.IP6'),                                   KEY_UNKNOWN],
+    #[ST_SKEY_IP4S,      ('Source.IP4',),                                                KEY_UNKNOWN],
+    #[ST_SKEY_IP6S,      ('Source.IP6',),                                                KEY_UNKNOWN],
+    [ST_SKEY_ANALYZERS,  ('Node[#].SW',),                                                KEY_UNKNOWN],
+    [ST_SKEY_CATEGORIES, ('Category',),                                                  KEY_UNKNOWN],
+    [ST_SKEY_DETECTORS,  ('Node[#].Name',),                                              KEY_UNKNOWN],
+    [ST_SKEY_ABUSES,     ('_Mentat.ResolvedAbuses', '_CESNET.ResolvedAbuses'),           KEY_UNKNOWN],
+    [ST_SKEY_ASNS,       ('_Mentat.SourceResolvedASN', '_CESNET.SourceResolvedASN'),     KEY_UNKNOWN],
+    [ST_SKEY_COUNTRIES,  ('_Mentat.SourceResolvedCountry', '_CESNET.SourceResolvedASN'), KEY_UNKNOWN],
+    [ST_SKEY_CLASSES,    ('_Mentat.EventClass', '_CESNET.SourceResolvedASN'),            KEY_UNKNOWN],
+    [ST_SKEY_SEVERITIES, ('_Mentat.EventSeverity', '_CESNET.SourceResolvedASN'),         KEY_UNKNOWN]
 )
 """List of statistical aggregations."""
 
@@ -532,7 +532,8 @@ def evaluate_dbstats_events(stats):
 
 def group_events(events):
     """
-    Group events according to the presence of the ``_CESNET.ResolvedAbuses`` key.
+    Group events according to the presence of the ``_Mentat.ResolvedAbuses`` (or 
+    ``_CESNET.ResolvedAbuses``) key.
     Each event will be added to group ``overall`` and then to either ``internal``,
     or ``external`` based on the presence of the key mentioned above.
 
@@ -543,7 +544,7 @@ def group_events(events):
     result = {ST_OVERALL: [], ST_INTERNAL: [], ST_EXTERNAL: []}
     for msg in events:
         result[ST_OVERALL].append(msg)
-        values = jpath_values(msg, '_CESNET.ResolvedAbuses')
+        values = jpath_values(msg, '_Mentat.ResolvedAbuses') or jpath_values(msg, '_CESNET.ResolvedAbuses')
         if values:
             result[ST_INTERNAL].append(msg)
         else:
@@ -819,7 +820,9 @@ def _include_event_to_stats(stats, event, recurring = False, skip = None):
         if skip and rule[0] in skip:
             continue
 
-        values = jpath_values(event, rule[1])
+        values = []
+        for jpath in rule[1]:
+            values = values + jpath_values(event, jpath)
         reg[rule[0]] = values
 
         if not values:
@@ -909,7 +912,8 @@ def _include_report_to_stats(stats, report):
 
         # This fixes the bug with missing part of the timeline chart where some
         # data was not yet being generated.
-        _counter_inc(stats, ST_SKEY_ABUSES, report.group.name, report.evcount_all)
+        for group in report.groups:
+            _counter_inc(stats, ST_SKEY_ABUSES, group.name, report.evcount_all)
 
     # Include the 'extra' report into the overall statistics.
     else:
