@@ -1020,7 +1020,7 @@ class RrdStats:
 
         try:
             rrdargs = chspec['def_args'] + chspec['draw_args']
-            result = rrdtool.graphv(
+            rrdtool.graph(
                 chspec['path_chart'],
                 '--width',            '{}'.format(DFLT_WIDTH),
                 '--height',           '{}'.format(DFLT_HEIGHT),
@@ -1054,7 +1054,7 @@ class RrdStats:
 
         try:
             rrdargs = chspec['def_args'] + chspec['draw_args']
-            result = rrdtool.graphv(
+            rrdtool.graph(
                 chspec['path_schart'],
                 '--width',  '{}'.format(DFLT_SPARK_WIDTH),
                 '--height', '{}'.format(DFLT_SPARK_HEIGHT),
