@@ -47,7 +47,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                     "SW": ["Kippo"]
                 }
             ],
-            "_CESNET" : {
+            "_Mentat" : {
                 "ResolvedAbuses" : [
                     "abuse@cesnet.cz"
                 ]
@@ -73,7 +73,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                     "SW": ["Kippo"]
                 }
             ],
-            "_CESNET" : {
+            "_Mentat" : {
                 "ResolvedAbuses" : [
                     "abuse@cesnet.cz"
                 ]
@@ -99,7 +99,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                     "SW": ["Kippo"]
                 }
             ],
-            "_CESNET" : {
+            "_Mentat" : {
                 "ResolvedAbuses" : [
                     "abuse@cesnet.cz"
                 ]
@@ -144,7 +144,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                     "SW": ["LaBrea"]
                 }
             ],
-            "_CESNET" : {
+            "_Mentat" : {
                 "ResolvedAbuses" : [
                     "abuse@cesnet.cz"
                 ]
@@ -397,7 +397,8 @@ class TestMentatStatsIdea(unittest.TestCase):
                 '192.168.0.2-192.168.0.5': 3,
                 '192.168.0.200': 1,
                 '192.172.0.109': 1,
-                '192.172.0.200': 1
+                '192.172.0.200': 1,
+                '2001:db8::ff00:42:0/112': 3
             },
             'list_ids': ['msg01', 'msg02', 'msg03', 'msg04', 'msg05', 'msg06'],
             'severities': {'__unknown__': 6}
@@ -427,7 +428,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                 'detectorsws': {'__REST__': 3,
                                 'cz.cesnet.holly/Beekeeper': 1,
                                 'org.example.kippo/Kippo': 2},
-                'ips': {'192.168.0.0/25': 3, '192.168.0.2-192.168.0.5': 3, '__REST__': 6},
+                'ips': {'192.168.0.0/25': 3, '192.168.0.2-192.168.0.5': 3, '__REST__': 9},
                 'severities': {'__unknown__': 6}
             }
         )
@@ -455,7 +456,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                                 'org.example.dionaea/Kippo': 1,
                                 'org.example.kippo/Kippo': 2,
                                 'org.example.labrea/LaBrea': 1},
-                'ips': {'192.168.0.0/25': 3, '__REST__': 9},
+                'ips': {'192.168.0.0/25': 3, '__REST__': 12},
                 'severities': {'__unknown__': 6}
             }
         )
@@ -509,7 +510,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                         'Source': [{'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25'],
                                     'IP6': ['2001:db8::ff00:42:0/112'],
                                     'Type': ['Phishing']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Fraud.Phishing'],
@@ -523,7 +524,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                         'Source': [{'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25'],
                                     'IP6': ['2001:db8::ff00:42:0/112'],
                                     'Type': ['Phishing']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Fraud.Phishing'],
@@ -537,7 +538,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                         'Source': [{'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25'],
                                     'IP6': ['2001:db8::ff00:42:0/112'],
                                     'Type': ['Phishing']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Exploit'],
@@ -550,7 +551,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                                   'Tags': ['Protocol', 'Honeypot']}],
                         'Source': [{'IP4': ['192.168.0.109', '192.168.0.200'],
                                     'Type': ['Exploit']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     }
                 ],
                 'stats_overall': [
@@ -566,7 +567,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                         'Source': [{'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25'],
                                     'IP6': ['2001:db8::ff00:42:0/112'],
                                     'Type': ['Phishing']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Fraud.Phishing'],
@@ -580,7 +581,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                         'Source': [{'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25'],
                                     'IP6': ['2001:db8::ff00:42:0/112'],
                                     'Type': ['Phishing']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Fraud.Phishing'],
@@ -594,7 +595,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                         'Source': [{'IP4': ['192.168.0.2-192.168.0.5', '192.168.0.0/25'],
                                     'IP6': ['2001:db8::ff00:42:0/112'],
                                     'Type': ['Phishing']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Spam'],
@@ -619,7 +620,7 @@ class TestMentatStatsIdea(unittest.TestCase):
                                   'Tags': ['Protocol', 'Honeypot']}],
                         'Source': [{'IP4': ['192.168.0.109', '192.168.0.200'],
                                     'Type': ['Exploit']}],
-                        '_CESNET': {'ResolvedAbuses': ['abuse@cesnet.cz']}
+                        '_Mentat': {'ResolvedAbuses': ['abuse@cesnet.cz']}
                     },
                     {
                         'Category': ['Exploit'],
@@ -696,7 +697,8 @@ class TestMentatStatsIdea(unittest.TestCase):
                         '192.168.0.2-192.168.0.5': 9,
                         '192.168.0.200': 3,
                         '192.172.0.109': 3,
-                        '192.172.0.200': 3},
+                        '192.172.0.200': 3,
+                        '2001:db8::ff00:42:0/112': 9},
                 'severities': {'__unknown__': 18}
             }
         )
