@@ -321,6 +321,8 @@ class TestMentatStatsRrd(unittest.TestCase):
         self.test_04_update()
 
         result = self.stats.lookup()
+        self.assertIsInstance(result, list)
+        self.assertTrue(result)     # Not empty
 
     def test_08_generate(self):
         """
