@@ -83,15 +83,15 @@ OVERALL_STATUS_MESSAGES = {
 }
 
 
-REGEXP_MENTAT_PS     = re.compile(r'\s*(\d+)\s+([^\s]+)\s+([^\s]*(?:python3?))\s+[^\s]+(mentat-[^\s]+)(?:\s+(.*))?')
+REGEXP_MENTAT_PS     = re.compile(r'\s*(\d+)\s+([^\s]+)\s+([^\s]*(?:python(?:\d+(?:\.\d+)?)?))\s+[^\s]+(mentat-[^\s]+)(?:\s+(.*))?')
 """Regular expression for selecting Mentat related processes."""
-REGEXP_MENTAT_PIDF   = re.compile(r'(.+?)(?:\.(\d+))?\.pid$')
+REGEXP_MENTAT_PIDF   = re.compile(r'(.+?)(?:\.([0-9a-fA-F]+))?\.pid$')
 """Regular expression for selecting Mentat related PID files."""
 REGEXP_MENTAT_CRONF  = re.compile(r'(.+)\.cron$')
 """Regular expression for selecting Mentat related log files."""
 REGEXP_MENTAT_LOGF   = re.compile(r'(.+)\.log$')
 """Regular expression for selecting Mentat related log files."""
-REGEXP_MENTAT_RLOGF  = re.compile(r'(.+)(?:\.(\d+))?\.runlog$')
+REGEXP_MENTAT_RLOGF  = re.compile(r'(.+)(?:\.([0-9a-fA-F]+))?\.runlog$')
 """Regular expression for selecting Mentat related runlog files."""
 REGEXP_MENTAT_CACHEF = re.compile(r'(.+)\.json$')
 """Regular expression for selecting Mentat related cache files."""
