@@ -15,6 +15,7 @@ import sys
 import traceback
 import datetime
 import weakref
+import json
 import jinja2
 
 import werkzeug.routing
@@ -84,7 +85,7 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
         """
         Application icon registry.
         """
-        return vial.const.FA_ICONS
+        return self.config.get('ICONS')
 
     @flask.app.setupmethod
     def add_url_rule(self, rule, endpoint = None, view_func = None, provide_automatic_options = None, **options):
@@ -102,13 +103,13 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
                     endpoint
                 )
                 return
-        self.logger.debug(  # pylint: disable=locally-disabled,no-member
-            "Registering URL route %s:%s:%s:%s",
-            str(rule),
-            str(endpoint),
-            str(view_func),
-            str(view_func.view_class) if hasattr(view_func, 'view_class') else '---none---',
-        )
+        #self.logger.debug(  # pylint: disable=locally-disabled,no-member
+        #    "Registering URL route %s:%s:%s:%s",
+        #    str(rule),
+        #    str(endpoint),
+        #    str(view_func),
+        #    str(view_func.view_class) if hasattr(view_func, 'view_class') else '---none---',
+        #)
         super().add_url_rule(rule, endpoint, view_func, provide_automatic_options, **options)
 
     def register_blueprint(self, blueprint, **options):
@@ -481,8 +482,7 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
 
             def get_icon(icon_name, default_icon = 'missing-icon'):
                 """
-                Get HTML icon markup for given icon. The icon will be looked up in
-                the :py:const:`vial.const.FA_ICONS` lookup table.
+                Get HTML icon markup for given icon.
 
                 :param str icon_name: Name of the icon.
                 :param str default_icon: Name of the default icon.
@@ -490,9 +490,9 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
                 :rtype: flask.Markup
                 """
                 return flask.Markup(
-                    vial.const.FA_ICONS.get(
+                    self.config.get('ICONS').get(
                         icon_name,
-                        vial.const.FA_ICONS.get(default_icon)
+                        self.config.get('ICONS').get(default_icon)
                     )
                 )
 
@@ -506,9 +506,9 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
                 :rtype: flask.Markup
                 """
                 return flask.Markup(
-                    vial.const.FA_ICONS.get(
+                    self.config.get('ICONS').get(
                         self.get_endpoint_class(endpoint).module_ref().get_module_icon(),
-                        vial.const.FA_ICONS.get(default_icon)
+                        self.config.get('ICONS').get(default_icon)
                     )
                 )
 
@@ -521,9 +521,9 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
                 :rtype: flask.Markup
                 """
                 return flask.Markup(
-                    vial.const.FA_ICONS.get(
+                    self.config.get('ICONS').get(
                         self.get_endpoint_class(endpoint).get_view_icon(),
-                        vial.const.FA_ICONS.get(default_icon)
+                        self.config.get('ICONS').get(default_icon)
                     )
                 )
 
@@ -591,6 +591,14 @@ class Vial(flask.Flask):  # pylint: disable=locally-disabled,too-many-instance-a
                 make_copy_deep      = vial.utils.make_copy_deep
             )
 
+        @self.template_filter('tojson_pretty')
+        def to_pretty_json(value):
+            return json.dumps(
+                value,
+                sort_keys = True,
+                indent = 4
+            )
+
         class VialJSONEncoder(flask.json.JSONEncoder):
             """
             Custom JSON encoder for converting anything into JSON strings.
@@ -1011,15 +1019,15 @@ class VialBlueprint(flask.Blueprint):
         # Obtain view function.
         view_func = view_class.as_view(view_class.get_view_name())
 
-        # Apply authentication decorators (if requested).
-        if view_class.authentication:
-            view_func = flask_login.login_required(view_func)
-
         # Apply authorization decorators (if requested).
         if view_class.authorization:
             for auth in view_class.authorization:
                 view_func = auth.require(403)(view_func)
 
+        # Apply authentication decorators (if requested).
+        if view_class.authentication:
+            view_func = flask_login.login_required(view_func)
+
         # Register endpoint to the application.
         self.add_url_rule(route_spec, view_func = view_func)
 
