@@ -140,10 +140,6 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
                 query = query.filter(model.enabled == True)
             elif form_args['state'] == 'disabled':
                 query = query.filter(model.enabled == False)
-            elif form_args['state'] == 'managed':
-                query = query.filter(model.managed == True)
-            elif form_args['state'] == 'notmanaged':
-                query = query.filter(model.managed == False)
         # Adjust query based on record source selection.
         if 'source' in form_args and form_args['source']:
             query = query\
@@ -275,6 +271,16 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
             'more.remove_membership',
             endpoint = 'users.removemembership'
         )
+        action_menu.add_entry(
+            'endpoint',
+            'more.add_management',
+            endpoint = 'users.addmanagement'
+        )
+        action_menu.add_entry(
+            'endpoint',
+            'more.remove_management',
+            endpoint = 'users.removemanagement'
+        )
         action_menu.add_entry(
             'endpoint',
             'more.enable',
@@ -659,8 +665,6 @@ class RemoveMemberView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # p
             group_id = flask.escape(str(kwargs['item']))
         )
 
-    #---------------------------------------------------------------------------
-
     @property
     def dbmodel(self):
         return self.get_model(vial.const.MODEL_GROUP)
@@ -691,8 +695,6 @@ class RemoveMemberView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # p
     def change_item(cls, **kwargs):
         kwargs['item'].members.remove(kwargs['other'])
 
-    #---------------------------------------------------------------------------
-
     @staticmethod
     def get_message_success(**kwargs):
         return gettext(
@@ -718,6 +720,181 @@ class RemoveMemberView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # p
         )
 
 
+class AddManagerView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # pylint: disable=locally-disabled,too-many-ancestors
+    """
+    View for adding group managers.
+    """
+    methods = ['GET','POST']
+
+    authentication = True
+
+    @classmethod
+    def get_view_name(cls):
+        return 'addmanager'
+
+    @classmethod
+    def get_view_title(cls, **kwargs):
+        return gettext('Add group manager')
+
+    @classmethod
+    def get_view_icon(cls):
+        return 'action-add-manager'
+
+    @classmethod
+    def get_menu_legend(cls, **kwargs):
+        return lazy_gettext(
+            'Add user &quot;%(user_id)s&quot; to group &quot;%(group_id)s&quot; as manager',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+    @property
+    def dbmodel(self):
+        return self.get_model(vial.const.MODEL_GROUP)
+
+    @property
+    def dbchlogmodel(self):
+        return self.get_model(vial.const.MODEL_ITEM_CHANGELOG)
+
+    @property
+    def dbmodel_other(self):
+        return self.get_model(vial.const.MODEL_USER)
+
+    @classmethod
+    def authorize_item_action(cls, **kwargs):
+        permission_m = flask_principal.Permission(
+            vial.acl.ManagementNeed(kwargs['item'].id)
+        )
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+
+    @classmethod
+    def validate_item_change(cls, **kwargs):  # pylint: disable=locally-disabled,unused-argument
+        # Reject item change in case given item is already manager.
+        if kwargs['other'] in kwargs['item'].managers:
+            return False
+        return True
+
+    @classmethod
+    def change_item(cls, **kwargs):
+        kwargs['item'].managers.append(kwargs['other'])
+        if kwargs['other'].is_state_disabled():
+            kwargs['other'].set_state_enabled()
+            flask.current_app.send_infomail(
+                'users.enable',
+                account = kwargs['other']
+            )
+
+    @staticmethod
+    def get_message_success(**kwargs):
+        return gettext(
+            'User <strong>%(user_id)s</strong> was successfully added as a manager to group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+    @staticmethod
+    def get_message_failure(**kwargs):
+        return gettext(
+            'Unable to add user <strong>%(user_id)s</strong> as a manager to group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+    @staticmethod
+    def get_message_cancel(**kwargs):
+        return gettext(
+            'Canceled adding user <strong>%(user_id)s</strong> as a manager to group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+
+class RemoveManagerView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # pylint: disable=locally-disabled,too-many-ancestors
+    """
+    View for removing group managers.
+    """
+    methods = ['GET','POST']
+
+    authentication = True
+
+    @classmethod
+    def get_view_name(cls):
+        return 'removemanager'
+
+    @classmethod
+    def get_view_title(cls, **kwargs):
+        return gettext('Remove group manager')
+
+    @classmethod
+    def get_view_icon(cls):
+        return 'action-rem-manager'
+
+    @classmethod
+    def get_menu_legend(cls, **kwargs):
+        return lazy_gettext(
+            'Remove user &quot;%(user_id)s&quot; from group &quot;%(group_id)s&quot; as manager',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+    @property
+    def dbmodel(self):
+        return self.get_model(vial.const.MODEL_GROUP)
+
+    @property
+    def dbchlogmodel(self):
+        return self.get_model(vial.const.MODEL_ITEM_CHANGELOG)
+
+    @property
+    def dbmodel_other(self):
+        return self.get_model(vial.const.MODEL_USER)
+
+    @classmethod
+    def authorize_item_action(cls, **kwargs):
+        permission_m = flask_principal.Permission(
+            vial.acl.ManagementNeed(kwargs['item'].id)
+        )
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+
+    @classmethod
+    def validate_item_change(cls, **kwargs):  # pylint: disable=locally-disabled,unused-argument
+        # Reject item change in case given item is not already manager.
+        if kwargs['other'] not in kwargs['item'].managers:
+            return False
+        return True
+
+    @classmethod
+    def change_item(cls, **kwargs):
+        try:
+            kwargs['item'].managers.remove(kwargs['other'])
+        except ValueError:
+            pass
+
+    @staticmethod
+    def get_message_success(**kwargs):
+        return gettext(
+            'User <strong>%(user_id)s</strong> was successfully removed as a manager from group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+    @staticmethod
+    def get_message_failure(**kwargs):
+        return gettext(
+            'Unable to remove user <strong>%(user_id)s</strong> as a manager from group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+    @staticmethod
+    def get_message_cancel(**kwargs):
+        return gettext(
+            'Canceled removing user <strong>%(user_id)s</strong> as a manager from group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['other'])),
+            group_id = flask.escape(str(kwargs['item']))
+        )
+
+
 class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for enabling existing groups.
@@ -914,16 +1091,18 @@ def get_blueprint():
         url_prefix = '/{}'.format(BLUEPRINT_NAME)
     )
 
-    hbp.register_view_class(ListView,         '/list')
-    hbp.register_view_class(CreateView,       '/create')
-    hbp.register_view_class(ShowView,         '/<int:item_id>/show')
-    hbp.register_view_class(ShowByNameView,   '/<item_id>/show_by_name')
-    hbp.register_view_class(UpdateView,       '/<int:item_id>/update')
-    hbp.register_view_class(AddMemberView,    '/<int:item_id>/add_member/<int:other_id>')
-    hbp.register_view_class(RejectMemberView, '/<int:item_id>/reject_member/<int:other_id>')
-    hbp.register_view_class(RemoveMemberView, '/<int:item_id>/remove_member/<int:other_id>')
-    hbp.register_view_class(EnableView,       '/<int:item_id>/enable')
-    hbp.register_view_class(DisableView,      '/<int:item_id>/disable')
-    hbp.register_view_class(DeleteView,       '/<int:item_id>/delete')
+    hbp.register_view_class(ListView,          '/list')
+    hbp.register_view_class(CreateView,        '/create')
+    hbp.register_view_class(ShowView,          '/<int:item_id>/show')
+    hbp.register_view_class(ShowByNameView,    '/<item_id>/show_by_name')
+    hbp.register_view_class(UpdateView,        '/<int:item_id>/update')
+    hbp.register_view_class(AddMemberView,     '/<int:item_id>/add_member/<int:other_id>')
+    hbp.register_view_class(RejectMemberView,  '/<int:item_id>/reject_member/<int:other_id>')
+    hbp.register_view_class(RemoveMemberView,  '/<int:item_id>/remove_member/<int:other_id>')
+    hbp.register_view_class(AddManagerView,    '/<int:item_id>/add_manager/<int:other_id>')
+    hbp.register_view_class(RemoveManagerView, '/<int:item_id>/remove_manager/<int:other_id>')
+    hbp.register_view_class(EnableView,        '/<int:item_id>/enable')
+    hbp.register_view_class(DisableView,       '/<int:item_id>/disable')
+    hbp.register_view_class(DeleteView,        '/<int:item_id>/delete')
 
     return hbp
