@@ -52,19 +52,6 @@ class BaseGroupForm(vial.forms.BaseItemForm):
         ],
         description = lazy_gettext('Origin of the group record, whether it was added manually, or via some automated mechanism from data from some third party system.')
     )
-    managed = wtforms.RadioField(
-        lazy_gettext('Self management:'),
-        validators = [
-            wtforms.validators.InputRequired(),
-        ],
-        choices = [
-            (True,  lazy_gettext('Enabled')),
-            (False, lazy_gettext('Disabled'))
-        ],
-        filters = [vial.forms.str_to_bool],
-        coerce = vial.forms.str_to_bool,
-        description = lazy_gettext('Boolean flag whether the group is self managed by group managers. When enabled group managers are expected to take care of the group management tasks and they get notifications about important events like group membership requests, etc.')
-    )
     members = QuerySelectMultipleField(
         lazy_gettext('Members:'),
         query_factory = vial.forms.get_available_users,
@@ -200,9 +187,7 @@ class GroupSearchForm(vial.forms.BaseSearchForm):
         choices = [
             ('', lazy_gettext('Nothing selected')),
             ('enabled',  lazy_gettext('Enabled')),
-            ('disabled', lazy_gettext('Disabled')),
-            ('managed',  lazy_gettext('Self-managed')),
-            ('notmanaged', lazy_gettext('Not self-managed'))
+            ('disabled', lazy_gettext('Disabled'))
         ],
         default = '',
         description = lazy_gettext('Search for groups with particular state.')
