@@ -147,8 +147,7 @@ class GroupsCreateTestCase(TestRunnerMixin, ItemCreateVialTestCase):
     group_data_fixture = [
         ('name', 'TEST_GROUP'),
         ('description', 'Test group for unit testing purposes.'),
-        ('enabled', True),
-        ('managed', True)
+        ('enabled', True)
     ]
 
     def _attempt_fail(self):
