@@ -153,7 +153,7 @@ class ListView(HTMLMixin, SQLAlchemyMixin, ItemListView):
             query = query\
                 .join(model.memberships)\
                 .filter(model.memberships.any(id = form_args['membership'].id))
-        # Adjust query based on user membership selection.
+        # Adjust query based on user management selection.
         if 'management' in form_args and form_args['management']:
             query = query\
                 .join(model.managements)\
@@ -272,6 +272,16 @@ class ShowView(HTMLMixin, SQLAlchemyMixin, ItemShowView):
             'more.remove_member',
             endpoint = 'groups.removemember'
         )
+        action_menu.add_entry(
+            'endpoint',
+            'more.add_manager',
+            endpoint = 'groups.addmanager'
+        )
+        action_menu.add_entry(
+            'endpoint',
+            'more.remove_manager',
+            endpoint = 'groups.removemanager'
+        )
         action_menu.add_entry(
             'endpoint',
             'more.enable',
@@ -803,6 +813,181 @@ class RemoveMembershipView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):
         )
 
 
+class AddManagementView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # pylint: disable=locally-disabled,too-many-ancestors
+    """
+    View for adding group managements.
+    """
+    methods = ['GET','POST']
+
+    authentication = True
+
+    @classmethod
+    def get_view_name(cls):
+        return 'addmanagement'
+
+    @classmethod
+    def get_view_title(cls, **kwargs):
+        return gettext('Add group management')
+
+    @classmethod
+    def get_view_icon(cls):
+        return 'action-add-manager'
+
+    @classmethod
+    def get_menu_legend(cls, **kwargs):
+        return lazy_gettext(
+            'Add user &quot;%(user_id)s&quot; to group &quot;%(group_id)s&quot; as manager',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+    @property
+    def dbmodel(self):
+        return self.get_model(vial.const.MODEL_USER)
+
+    @property
+    def dbmodel_other(self):
+        return self.get_model(vial.const.MODEL_GROUP)
+
+    @property
+    def dbchlogmodel(self):
+        return self.get_model(vial.const.MODEL_ITEM_CHANGELOG)
+
+    @classmethod
+    def authorize_item_action(cls, **kwargs):
+        permission_m = flask_principal.Permission(
+            vial.acl.ManagementNeed(kwargs['other'].id)
+        )
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+
+    @classmethod
+    def validate_item_change(cls, **kwargs):  # pylint: disable=locally-disabled,unused-argument
+        # Reject item change in case given item is already manager.
+        if kwargs['other'] in kwargs['item'].managements:
+            return False
+        return True
+
+    @classmethod
+    def change_item(cls, **kwargs):
+        kwargs['item'].managements.append(kwargs['other'])
+        if kwargs['item'].is_state_disabled():
+            kwargs['item'].set_state_enabled()
+            flask.current_app.send_infomail(
+                'users.enable',
+                account = kwargs['item']
+            )
+
+    @staticmethod
+    def get_message_success(**kwargs):
+        return gettext(
+            'User <strong>%(user_id)s</strong> was successfully added as a manager to group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+    @staticmethod
+    def get_message_failure(**kwargs):
+        return gettext(
+            'Unable to add user <strong>%(user_id)s</strong> as a manager to group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+    @staticmethod
+    def get_message_cancel(**kwargs):
+        return gettext(
+            'Canceled adding user <strong>%(user_id)s</strong> as a manager to group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+
+class RemoveManagementView(HTMLMixin, SQLAlchemyMixin, ItemObjectRelationView):  # pylint: disable=locally-disabled,too-many-ancestors
+    """
+    View for removing group managements.
+    """
+    methods = ['GET','POST']
+
+    authentication = True
+
+    @classmethod
+    def get_view_name(cls):
+        return 'removemanagement'
+
+    @classmethod
+    def get_view_title(cls, **kwargs):
+        return gettext('Remove group management')
+
+    @classmethod
+    def get_view_icon(cls):
+        return 'action-rem-manager'
+
+    @classmethod
+    def get_menu_legend(cls, **kwargs):
+        return lazy_gettext(
+            'Remove user &quot;%(user_id)s&quot; from group &quot;%(group_id)s&quot; as manager',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+    @property
+    def dbmodel(self):
+        return self.get_model(vial.const.MODEL_USER)
+
+    @property
+    def dbmodel_other(self):
+        return self.get_model(vial.const.MODEL_GROUP)
+
+    @property
+    def dbchlogmodel(self):
+        return self.get_model(vial.const.MODEL_ITEM_CHANGELOG)
+
+    @classmethod
+    def authorize_item_action(cls, **kwargs):
+        permission_m = flask_principal.Permission(
+            vial.acl.ManagementNeed(kwargs['other'].id)
+        )
+        return vial.acl.PERMISSION_POWER.can() or permission_m.can()
+
+    @classmethod
+    def validate_item_change(cls, **kwargs):  # pylint: disable=locally-disabled,unused-argument
+        # Reject item change in case given item is not already manager.
+        if kwargs['other'] not in kwargs['item'].managements:
+            return False
+        return True
+
+    @classmethod
+    def change_item(cls, **kwargs):
+        try:
+            kwargs['item'].managements.remove(kwargs['other'])
+        except ValueError:
+            pass
+
+    @staticmethod
+    def get_message_success(**kwargs):
+        return gettext(
+            'User <strong>%(user_id)s</strong> was successfully removed as a manager from group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+    @staticmethod
+    def get_message_failure(**kwargs):
+        return gettext(
+            'Unable to remove user <strong>%(user_id)s</strong> as a manager from group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+    @staticmethod
+    def get_message_cancel(**kwargs):
+        return gettext(
+            'Canceled removing user <strong>%(user_id)s</strong> as a manager from group <strong>%(group_id)s</strong>.',
+            user_id  = flask.escape(str(kwargs['item'])),
+            group_id = flask.escape(str(kwargs['other']))
+        )
+
+
 class EnableView(HTMLMixin, SQLAlchemyMixin, ItemEnableView):  # pylint: disable=locally-disabled,too-many-ancestors
     """
     View for enabling existing user accounts.
@@ -1036,6 +1221,8 @@ def get_blueprint():
     hbp.register_view_class(AddMembershipView,    '/<int:item_id>/add_membership/<int:other_id>')
     hbp.register_view_class(RemoveMembershipView, '/<int:item_id>/remove_membership/<int:other_id>')
     hbp.register_view_class(RejectMembershipView, '/<int:item_id>/reject_membership/<int:other_id>')
+    hbp.register_view_class(AddManagementView,    '/<int:item_id>/add_management/<int:other_id>')
+    hbp.register_view_class(RemoveManagementView, '/<int:item_id>/remove_management/<int:other_id>')
     hbp.register_view_class(EnableView,           '/<int:item_id>/enable')
     hbp.register_view_class(DisableView,          '/<int:item_id>/disable')
     hbp.register_view_class(DeleteView,           '/<int:item_id>/delete')
