@@ -61,9 +61,6 @@ class BaseUserAccountForm(vial.forms.BaseItemForm):
     submit = wtforms.SubmitField(
         lazy_gettext('Submit')
     )
-    cancel = wtforms.SubmitField(
-        lazy_gettext('Cancel')
-    )
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
