@@ -265,6 +265,8 @@ ICONS = {
     'action-add-member':   '<i class="fas fa-fw fa-user-plus"></i>',
     'action-rej-member':   '<i class="fas fa-fw fa-user-minus"></i>',
     'action-rem-member':   '<i class="fas fa-fw fa-user-times"></i>',
+    'action-add-manager':  '<i class="fas fa-fw fa-user-plus"></i>',
+    'action-rem-manager':  '<i class="fas fa-fw fa-user-times"></i>',
     'action-save':         '<i class="fas fa-fw fa-save"></i>',
     'action-download':     '<i class="fas fa-fw fa-file-download"></i>',
     'action-download-zip': '<i class="fas fa-fw fa-file-archive"></i>',
