@@ -62,6 +62,8 @@ def str_to_bool_with_none(value):
         return False
     if str(value).lower() == 'none':
         return None
+    if  str(value).lower() == '':
+        return ''
     raise ValueError('Invalid string value {} to be converted to boolean'.format(str(value)))
 
 
@@ -344,6 +346,17 @@ def get_available_users():
         order_by(user_model.fullname).\
         all()
 
+def get_available_group_sources():
+    """
+    Query the database for list of network record sources.
+    """
+    group_model = flask.current_app.get_model(vial.const.MODEL_GROUP)
+    result = vial.db.db_query(group_model)\
+        .distinct(group_model.source)\
+        .order_by(group_model.source)\
+        .all()
+    return [x.source for x in result]
+
 #-------------------------------------------------------------------------------
 
 
