@@ -313,13 +313,13 @@ class VialTestCase(unittest.TestCase):
 
     #--------------------------------------------------------------------------
 
-    def assertGetURL(self, url, status_code = 200, content_checks = None, print_response = False):  # pylint: disable=locally-disabled,invalid-name
+    def assertGetURL(self, url, status_code = 200, content_checks = None, print_response = False, follow_redirects = True):  # pylint: disable=locally-disabled,invalid-name
         """
         Perform GET request and check some default assertions against the response.
         """
         response = self.client.get(
             url,
-            follow_redirects = True
+            follow_redirects = follow_redirects
         )
         if print_response:
             print("--------------------------------------------------------------------------------")
@@ -333,14 +333,14 @@ class VialTestCase(unittest.TestCase):
                 self.assertTrue(cch in response.data)
         return response
 
-    def assertPostURL(self, url, data, status_code = 200, content_checks = None, print_response = False):  # pylint: disable=locally-disabled,invalid-name
+    def assertPostURL(self, url, data, status_code = 200, content_checks = None, print_response = False, follow_redirects = True):  # pylint: disable=locally-disabled,invalid-name
         """
         Perform POST request and check some default assertions against the response.
         """
         response = self.client.post(
             url,
             data = data,
-            follow_redirects = True
+            follow_redirects = follow_redirects
         )
         if print_response:
             print("--------------------------------------------------------------------------------")
