@@ -542,6 +542,8 @@ class BaseLoginView(SimpleView):
     Base class for login views.
     """
 
+    is_sign_in = True
+
     @classmethod
     def get_view_name(cls):
         return vial.const.ACTION_USER_LOGIN
@@ -1307,10 +1309,7 @@ class ItemShowView(RenderableView):  # pylint: disable=locally-disabled,abstract
         action_menu.add_entry(
             'endpoint',
             'list',
-            endpoint = '{}.{}'.format(
-                cls.module_name,
-                cls.get_view_endpoint_name().replace('show', 'list')
-            ),
+            endpoint = '{}.list'.format(cls.module_name),
             paramlist = []
         )
         action_menu.add_entry(
@@ -1420,14 +1419,15 @@ class ItemActionView(RenderableView):  # pylint: disable=locally-disabled,abstra
         """
         *Hook method*. Check the form for *cancel* button press and cancel the action.
         """
-        if getattr(form, vial.const.FORM_ACTION_CANCEL).data:
-            self.flash(
-                flask.Markup(self.get_message_cancel(**kwargs)),
-                vial.const.FLASH_INFO
-            )
-            return self.redirect(
-                default_url = self.get_url_next()
-            )
+        if hasattr(form, vial.const.FORM_ACTION_CANCEL):
+            if getattr(form, vial.const.FORM_ACTION_CANCEL).data:
+                self.flash(
+                    flask.Markup(self.get_message_cancel(**kwargs)),
+                    vial.const.FLASH_INFO
+                )
+                return self.redirect(
+                    default_url = self.get_url_next()
+                )
 
         return None
 
@@ -1590,10 +1590,7 @@ class ItemCreateView(ItemActionView):  # pylint: disable=locally-disabled,abstra
         breadcrumbs_menu.add_entry(
             'endpoint',
             'list',
-            endpoint = '{}.{}'.format(
-                cls.module_name,
-                cls.get_view_endpoint_name().replace('create', 'list')
-            ),
+            endpoint = '{}.list'.format(cls.module_name)
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
@@ -1892,6 +1889,8 @@ class BaseRegisterView(ItemCreateView):  # pylint: disable=locally-disabled,abst
     """
     methods = ['GET', 'POST']
 
+    is_sign_up = True
+
     @classmethod
     def get_view_name(cls):
         return vial.const.ACTION_USER_REGISTER
@@ -1938,6 +1937,11 @@ class BaseRegisterView(ItemCreateView):  # pylint: disable=locally-disabled,abst
         Send information about new account registration to system
         admins. Use default locale for email content translations.
         """
+        flask.current_app.logger.info(
+            "Attempting to send information about registration of new account '{}' to system admins @: '{}'.".format(
+                account.login, ', '.join(flask.current_app.config['EMAIL_ADMINS'])
+            )
+        )
         mail_locale = flask.current_app.config['BABEL_DEFAULT_LOCALE']
         with force_locale(mail_locale):
             msg = flask_mail.Message(
@@ -1958,17 +1962,20 @@ class BaseRegisterView(ItemCreateView):  # pylint: disable=locally-disabled,abst
     @classmethod
     def inform_managers(cls, account, form_data):
         """
-        Send information about new account registration to the user.
+        Send information about new account registration to the group managers.
         Use manager`s locale for email content translations.
         """
         for group in account.memberships_wanted:
-            if not group.managed:
-                return
+            flask.current_app.logger.info(
+                "Attempting to send information about registration of new account '{}' to managers of group '{}'.".format(
+                    account.login, group.name
+                )
+            )
 
             if not group.managers:
-                flask.current_app.logger.error(
-                    "Group '{}' is marked as self-managed, but there are no managers.".format(
-                        group.name
+                flask.current_app.logger.info(
+                    "Unable to send information about registration of new account '{}' to managers of group '{}': there are no managers configured.".format(
+                        account.login, group.name
                     )
                 )
                 return
@@ -1994,6 +2001,11 @@ class BaseRegisterView(ItemCreateView):  # pylint: disable=locally-disabled,abst
                         justification = form_data['justification']
                     )
                     flask.current_app.mailer.send(msg)
+                    flask.current_app.logger.info(
+                        "Sent information about registration of new account '{}' to manager '{}' of group '{}'.".format(
+                            account.login, manager.email, group.name
+                        )
+                    )
 
     @classmethod
     def inform_user(cls, account, form_data):
@@ -2087,18 +2099,12 @@ class ItemUpdateView(ItemActionView):  # pylint: disable=locally-disabled,abstra
         breadcrumbs_menu.add_entry(
             'endpoint',
             'list',
-            endpoint = '{}.{}'.format(
-                cls.module_name,
-                cls.get_view_endpoint_name().replace('update', 'list')
-            )
+            endpoint = '{}.list'.format(cls.module_name)
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
             'show',
-            endpoint = '{}.{}'.format(
-                cls.module_name,
-                cls.get_view_endpoint_name().replace('update', 'show')
-            )
+            endpoint = '{}.show'.format(cls.module_name)
         )
         breadcrumbs_menu.add_entry(
             'endpoint',
